@@ -1,12 +1,8 @@
-/********************* -*- mode: C; coding: utf-8 -*- *************************/
 /**
- * \file
- *           Dialog helper functions.
- *
- * \author   Copyright (C) 2006, 2011, 2020 Ralf Hoppe <ralf.hoppe@dfcgen.de>
- *
- ******************************************************************************/
-
+ * \file        dialogSupport.h
+ * \brief       Dialog helper functions.
+ * \copyright   Copyright (C) 2006-2022 Ralf Hoppe <ralf.hoppe@dfcgen.de>
+ */
 
 #ifndef DLGSUPPORT_H
 #define DLGSUPPORT_H
@@ -115,6 +111,7 @@ extern "C" {
 /* FUNCTION *******************************************************************/
 /** A little popup dialog, where the user shall enter a double value.
  *
+ *  \param topWindow    Parent window.
  *  \param title        Title of window.
  *  \param label        Label to put before the GtkEntry text field.
  *  \param comment      An introduction displayed at top of the dialog (may be
@@ -124,7 +121,8 @@ extern "C" {
  *
  *  \return             TRUE on success, FALSE if the user has canceled.
  ******************************************************************************/
-    BOOL dlgPopupDouble (char *title, char *label, char *comment, double *pResult);
+    BOOL dlgPopupDouble (GtkWindow *topWindow, char *title, char *label,
+                         char *comment, double *pResult);
 
 
 #ifdef  __cplusplus
