@@ -1,12 +1,8 @@
-/********************* -*- mode: C; coding: utf-8 -*- *************************/
 /**
- * \file
- *           Response settings/properties dialog.
- *
- * \author   Copyright (C) 2006, 2011, 2020 Ralf Hoppe <ralf.hoppe@dfcgen.de>
- *
- ******************************************************************************/
-
+ * \file        responseDlg.h
+ * \brief       Response settings/properties dialog.
+ * \copyright   Copyright (C) 2006-2022 Ralf Hoppe <ralf.hoppe@dfcgen.de>
+ */
 
 #ifndef RESPONSE_DLG_H
 #define RESPONSE_DLG_H
@@ -41,11 +37,12 @@ extern "C" {
 /* FUNCTION *******************************************************************/
 /** Creates the properties dialog for a response plot.
  *
+ *  \param topWindow    Parent window.
  *  \param pDiag        Pointer to current plot configuration (for preset).
  *
  *  \return             Dialog widget.
  ******************************************************************************/
-    GtkWidget* responseDlgCreate (PLOT_DIAG *pDiag);
+    GtkWidget* responseDlgCreate (GtkWindow *topWindow, PLOT_DIAG *pDiag);
 
 
 /* FUNCTION *******************************************************************/
