@@ -1,11 +1,8 @@
-/********************* -*- mode: C; coding: utf-8 -*- *************************/
 /**
- * \file     cairoPlot.c
- * \brief    2-dimensional plot on a \e Cairo graphic context.
- *
- * \author   Copyright (C) 2006, 2011, 2012, 2020 Ralf Hoppe <ralf.hoppe@dfcgen.de>
- *
- ******************************************************************************/
+ * \file        cairoPlot.c
+ * \brief       2-dimensional plot on a \e Cairo graphic context.
+ * \copyright   Copyright (C) 2006-2022 Ralf Hoppe <ralf.hoppe@dfcgen.de>
+ */
 
 
 /* INCLUDE FILES **************************************************************/
@@ -95,10 +92,9 @@ typedef void (*PLOT_FUNC_DRAW)(cairo_t* cr, PLOT_AXIS_WORKSPACE* pY,
 
 
 /* MACRO **********************************************************************/
-/** Sets a color from \p colors array into \e Cairo context.
- *
- *  \note               Do not use the function gdk_cairo_set_source_color(),
- *                      because it does'nt work.
+/**
+ *  \brief  Sets a color from \p colors array into \e Cairo context (using
+ *          100% transparency).
  *
  *  \param cr           \e Cairo drawing context.
  *  \param colors       Pointer to array of GDK colors indexed by PLOT_COLOR.
@@ -106,12 +102,13 @@ typedef void (*PLOT_FUNC_DRAW)(cairo_t* cr, PLOT_AXIS_WORKSPACE* pY,
  *  \param index        Identifies the color (PLOT_COLOR) to be changed.
  *
  ******************************************************************************/
-#define PLOT_COLOR_SET(cr, colors, index)                               \
-    if ((colors) != NULL)                                               \
-    {                                                                   \
-        cairo_set_source_rgb ((cr), (colors)[(index)].red / 65535.0,    \
-                              (colors)[(index)].green / 65535.0,        \
-                              (colors)[(index)].blue / 65535.0);        \
+#define PLOT_COLOR_SET(cr, colors, index)                   \
+    if ((colors) != NULL)                                   \
+    {                                                       \
+        cairo_set_source_rgba ((cr), (colors)[(index)].red, \
+                              (colors)[(index)].green,      \
+                              (colors)[(index)].blue,       \
+                               1.0);                        \
     }
 
 
@@ -135,7 +132,7 @@ static void drawLayout(cairo_t *cr, PangoLayout* layout, int x, int y);
 static void createAxisNameLayout(cairo_t *cr, PLOT_AXIS_WORKSPACE *p);
 static BOOL insertLabel(cairo_t *cr, PLOT_AXIS_WORKSPACE *p, int margin,
                         BOOL vertical, double coordinate, int idx);
-static void drawGridLabels (cairo_t *cr, GdkColor *colors,
+static void drawGridLabels (cairo_t *cr, GdkRGBA *colors,
                             int numx, PLOT_AXIS_WORKSPACE* pX,
                             int numy, PLOT_AXIS_WORKSPACE* pY);
 static int drawGraph (cairo_t *cr, int refsize, PLOT_DIAG *pDiag,
@@ -537,8 +534,8 @@ static BOOL insertLabel(cairo_t *cr, PLOT_AXIS_WORKSPACE *p, int margin,
     {
         PLOT_LABEL* pLast = &p->labels[idx - 1];            /* previous label */
 
-        bad = abs(pLabel->grid - pLast->grid) <        /* check space between */
-            (margin + size + abs(pLast->grid - pLast->pos));
+        bad = (abs ((int)(pLabel->grid - pLast->grid)) < /* chk space between */
+               (margin + size + abs ((int)pLast->grid - pLast->pos)));
     } /* if */
 
     return bad;
@@ -717,7 +714,7 @@ static int scaleLog(cairo_t *cr, PLOT_AXIS_WORKSPACE *p, int margin, BOOL vertic
  *
  *  \return             0 on success, else an error number from errno.h.
  ******************************************************************************/
-static void drawGridLabels (cairo_t *cr, GdkColor *colors,
+static void drawGridLabels (cairo_t *cr, GdkRGBA *colors,
                             int numx, PLOT_AXIS_WORKSPACE* pX,
                             int numy, PLOT_AXIS_WORKSPACE* pY)
 {
@@ -726,7 +723,7 @@ static void drawGridLabels (cairo_t *cr, GdkColor *colors,
     int i;
     PLOT_LABEL *pLabel;
 
-    /* Set the color into Cairo context (using cairo_set_source_rgb) before
+    /* Set the color into Cairo context (using cairo_set_source_rgba) before
      * calling pango_cairo_show_layout(). It seems that a call to cairo_stroke
      * isn't needed, may be its implemented in pango_cairo_show_layout().
      */
@@ -1169,18 +1166,12 @@ static int drawGraph (cairo_t *cr, int size, PLOT_DIAG *pDiag,
     World      = 10^(log(WorldMin) + (Screen - ScreenMin)/DeltaRatio))
                = WorldMin*10^((Screen - ScreenMin)/DeltaRatio)
  *
- *  \param cr           \e Cairo context for drawing, which may be retrieved
- *                      by the help of following functions:
- *                      - gdk_cairo_create ()
- *                      - gtk_print_context_get_cairo_context().
- *                      Notice, that the \e Cairo context is preserved (nothing
- *                      chenged).
+ *  \param cr           \e Cairo context for drawing.
  *  \param pDiag        Pointer to plot descriptor.
  *
  *  \return             0 on success, else an error number from errno.h.
  *  \todo               Make axisX.start and axisX.stop positions dependent of
- *                      number of digits. Especially think about the corrections
- *                      of axisX.stop (which is an estimation at the moment).
+ *                      number of digits.
  ******************************************************************************/
 int cairoPlot2d(cairo_t* cr, PLOT_DIAG *pDiag)
 {
