@@ -1,11 +1,8 @@
-/********************* -*- mode: C; coding: utf-8 -*- *************************/
 /**
- * \file
- *           Design dialogs management.
- *
- * \author   Copyright (C) 2006, 2011, 2012, 2020 Ralf Hoppe <ralf.hoppe@dfcgen.de>
- *
- ******************************************************************************/
+ * \file        designDlg.c
+ * \brief       Design dialogs management.
+ * \copyright   Copyright (C) 2006-2022 Ralf Hoppe <ralf.hoppe@dfcgen.de>
+ */
 
 
 /* INCLUDE FILES **************************************************************/
@@ -88,29 +85,30 @@ static DESIGNDLG_DESC dlgDesc[FLTCLASS_SIZE] =
 
 /* LOCAL FUNCTION DECLARATIONS ************************************************/
 
-static void updateLayout (GtkWidget *topWidget, FLTCLASS type);
+static void designDlgAdopt (GtkWidget *topWidget, FLTCLASS type);
 
 
 /* LOCAL FUNCTION DEFINITIONS *************************************************/
 
 
 /* FUNCTION *******************************************************************/
-/** Updates the design layout.
+/** Adopt design dialog layout to passed-in filter class type.
  *
  *  \param topWidget    Top level widget.
  *  \param type         Filter class (may be FLTCLASS_NOTDEF).
  *
  ******************************************************************************/
-static void updateLayout (GtkWidget *topWidget, FLTCLASS type)
+static void designDlgAdopt (GtkWidget *topWidget, FLTCLASS type)
 {
     static FLTCLASS currentDlgType = FLTCLASS_NOTDEF;
 
     FLTCLASS i;
 
+    BOOL unspecified = (type < 0) || (type >= FLTCLASS_SIZE);
     GtkWidget* boxWidget = lookup_widget (topWidget, "boxDesignDlg");
     ASSERT (boxWidget != NULL);
 
-    if ((type < 0) || (type >= FLTCLASS_SIZE))
+    if (unspecified)
     {
         if (currentDlgType == FLTCLASS_NOTDEF)             /* the first call? */
         {
@@ -122,7 +120,7 @@ static void updateLayout (GtkWidget *topWidget, FLTCLASS type)
         } /* if */
     } /* if */
 
-    if (type != currentDlgType)
+    if (unspecified || (type != currentDlgType))
     {
         if (currentDlgType != FLTCLASS_NOTDEF)         /* not the first call? */
         {
@@ -137,7 +135,7 @@ static void updateLayout (GtkWidget *topWidget, FLTCLASS type)
         gtk_window_resize (GTK_WINDOW (topWidget), 1, 1); /* resize to minimum */
         currentDlgType = type;
     } /* if */
-} /* updateLayout() */
+} /* designDlgAdopt() */
 
 
 
@@ -166,15 +164,11 @@ void designDlgBoxRealize(GtkWidget *widget, gpointer user_data)
 
     for (index = 0; index < FLTCLASS_SIZE; index++)
     {
-        gtk_combo_box_append_text (GTK_COMBO_BOX (classWidget),
-                                   gettext (dlgDesc[index].name));
+        gtk_combo_box_text_append_text (GTK_COMBO_BOX_TEXT (classWidget),
+                                        gettext (dlgDesc[index].name));
     } /* for */
 
-#if GTK_CHECK_VERSION (2, 18, 0)
-    if (gtk_widget_is_toplevel (topWidget))                /* new since 2.18 */
-#else
-    if (GTK_WIDGET_TOPLEVEL (topWidget))            /* deprecated since 2.20 */
-#endif
+    if (gtk_widget_is_toplevel (topWidget))
     {
         index = dfcPrjGetDesign(NULL);
 
@@ -184,7 +178,7 @@ void designDlgBoxRealize(GtkWidget *widget, gpointer user_data)
         } /* if */
 
         /* The following call emits a "changed" event, which then forces
-         * execution of updateLayout().
+         * execution of designDlgAdopt().
          */
         gtk_combo_box_set_active (GTK_COMBO_BOX (classWidget), index);
     } /* if */
@@ -206,7 +200,7 @@ void designDlgOnFilterComboChanged (GtkComboBox* combobox, gpointer user_data)
 
     ASSERT (topWidget != NULL);
     ASSERT (index < FLTCLASS_SIZE);
-    updateLayout (topWidget, index);
+    designDlgAdopt (topWidget, index);
 
 } /* designDlgOnFilterComboChanged() */
 
@@ -223,7 +217,7 @@ void designDlgUpdate (GtkWidget *topWidget)
     DESIGNDLG design;
     FLTCLASS type = dfcPrjGetDesign (&design);
 
-    updateLayout (topWidget, type);
+    designDlgAdopt (topWidget, type);
 
     if (type != FLTCLASS_NOTDEF)
     {
