@@ -1,11 +1,8 @@
-/********************* -*- mode: C; coding: utf-8 -*- *************************/
 /**
- * \file     dialogSupport.c
- * \brief    Dialog helper functions.
- *
- * \author   Copyright (C) 2006, 2011, 2012, 2020 Ralf Hoppe <ralf.hoppe@dfcgen.de>
- *
- ******************************************************************************/
+ * \file        dialogSupport.c
+ * \brief       Dialog helper functions.
+ * \copyright   Copyright (C) 2006-2022 Ralf Hoppe <ralf.hoppe@dfcgen.de>
+ */
 
 
 /* INCLUDE FILES **************************************************************/
@@ -14,6 +11,7 @@
 #include "dialogSupport.h"
 #include "cfgSettings.h"
 
+#include <float.h>  /* DBL_DIG */
 #include <stdlib.h>
 #include <stdarg.h>
 #include <errno.h>
@@ -267,6 +265,7 @@ void dlgSetDouble (GtkWidget* topWidget, const char *name,
 /* FUNCTION *******************************************************************/
 /** A little popup dialog, where the user shall enter a double value.
  *
+ *  \param topWindow    Parent window.
  *  \param title        Title of window.
  *  \param label        Label to put before the GtkEntry text field.
  *  \param comment      An introduction displayed at top of the dialog (may be
@@ -276,37 +275,38 @@ void dlgSetDouble (GtkWidget* topWidget, const char *name,
  *
  *  \return             TRUE on success, FALSE if the user has canceled.
  ******************************************************************************/
-BOOL dlgPopupDouble (char *title, char *label, char *comment, double *pResult)
+BOOL dlgPopupDouble (GtkWindow *topWindow, char *title, char *label,
+                     char *comment, double *pResult)
 {
     BOOL ret;
     char text[128];
     GtkWidget *widget, *entry, *vbox, *hbox;
 
     GtkWidget *dialog = gtk_dialog_new ();
+    gtk_window_set_transient_for (GTK_WINDOW (dialog), topWindow);
+    gtk_window_set_destroy_with_parent (GTK_WINDOW (dialog), TRUE);
 
     gtk_window_set_title (GTK_WINDOW (dialog), title);
     gtk_window_set_type_hint (GTK_WINDOW (dialog), GDK_WINDOW_TYPE_HINT_DIALOG);
-
-    vbox = GTK_DIALOG (dialog)->vbox;
+    vbox = gtk_dialog_get_content_area (GTK_DIALOG (dialog));
+    gtk_container_set_border_width (GTK_CONTAINER (vbox), 6);
 
     if (comment != NULL)
     {
         widget = gtk_label_new (comment);
+        gtk_label_set_max_width_chars (GTK_LABEL (widget), GUI_LABEL_WRAP_CHARS);
         gtk_label_set_line_wrap (GTK_LABEL (widget), TRUE);
         gtk_label_set_use_markup (GTK_LABEL (widget), TRUE);
-        gtk_misc_set_padding (GTK_MISC (widget), 12, 0);
-        gtk_box_pack_start (GTK_BOX (vbox), widget, FALSE, FALSE, 12);
+        gtk_box_pack_start (GTK_BOX (vbox), widget, FALSE, FALSE, 6);
     } /* if */
 
-    hbox = gtk_hbox_new (FALSE, 0);
+    hbox = gtk_box_new (GTK_ORIENTATION_HORIZONTAL, 6);
     gtk_box_pack_start (GTK_BOX (vbox), hbox, TRUE, TRUE, 6);
-
     widget = gtk_label_new_with_mnemonic (label);
     gtk_box_pack_start (GTK_BOX (hbox), widget, FALSE, FALSE, 0);
-    gtk_misc_set_padding (GTK_MISC (widget), 12, 0);
 
     entry = gtk_entry_new ();
-    gtk_box_pack_start (GTK_BOX (hbox), entry, FALSE, TRUE, 0);
+    gtk_box_pack_start (GTK_BOX (hbox), entry, FALSE, FALSE, 0);
     gtk_entry_set_width_chars (GTK_ENTRY (entry), DBL_DIG);
     gtk_entry_set_activates_default (GTK_ENTRY (entry), TRUE);
     g_snprintf (text, sizeof(text), "%.*G", cfgGetDesktopPrefs()->outprec, *pResult);
@@ -314,16 +314,13 @@ BOOL dlgPopupDouble (char *title, char *label, char *comment, double *pResult)
     GLADE_HOOKUP_OBJECT (dialog, entry, "entry");
     gtk_label_set_mnemonic_widget (GTK_LABEL (widget), entry);
 
-    vbox = GTK_DIALOG (dialog)->action_area;
-    gtk_button_box_set_layout (GTK_BUTTON_BOX (vbox), GTK_BUTTONBOX_END);
-
-    widget = gtk_button_new_from_stock (GTK_STOCK_CANCEL);
+    widget = createImageButton (GUI_BUTTON_LABEL_CANCEL, GUI_BUTTON_IMAGE_CANCEL);
     gtk_dialog_add_action_widget (GTK_DIALOG (dialog), widget, GTK_RESPONSE_CANCEL);
-    GTK_WIDGET_SET_FLAGS (widget, GTK_CAN_DEFAULT);
+    gtk_widget_set_can_default (widget, TRUE);
 
-    widget = gtk_button_new_from_stock (GTK_STOCK_OK);
+    widget = createImageButton (GUI_BUTTON_LABEL_OK, GUI_BUTTON_IMAGE_OK);
     gtk_dialog_add_action_widget (GTK_DIALOG (dialog), widget, GTK_RESPONSE_OK);
-    GTK_WIDGET_SET_FLAGS (widget, GTK_CAN_DEFAULT);
+    gtk_widget_set_can_default (widget, TRUE);
     gtk_widget_grab_default (widget);
 
     gtk_widget_show_all (dialog);
