@@ -1,11 +1,8 @@
-/********************* -*- mode: C; coding: utf-8 -*- *************************/
 /**
- * \file     editDlg.c
- * \brief    \e Edit dialog(s).
- *
- * \author   Copyright (C) 2006, 2011, 2012, 2013, 2020 Ralf Hoppe <ralf.hoppe@dfcgen.de>
- *
- ******************************************************************************/
+ * \file        editDlg.c
+ * \brief       Edit dialog(s).
+ * \copyright   Copyright (C) 2006-2022 Ralf Hoppe <ralf.hoppe@dfcgen.de>
+ */
 
 
 /* INCLUDE FILES **************************************************************/
@@ -75,8 +72,8 @@ static PLOT_UNIT unitT[] =
 /* LOCAL FUNCTION DECLARATIONS ************************************************/
 
 static char *dupInfoStr (const char* info);
-static GtkWidget* createInfoDlg (const DFCPRJ_INFO *pInfo);
-static GtkWidget* createSettingsDlg (const CFG_DESKTOP* pPrefs);
+static GtkWidget* createInfoDlg (GtkWidget *topWidget, const DFCPRJ_INFO *pInfo);
+static GtkWidget* createSettingsDlg (GtkWidget *topWidget, const CFG_DESKTOP* pPrefs);
 static int searchUnit (PLOT_UNIT units[], int size, const char* unitName);
 static GtkResponseType editDlgSettingsAccept (GtkWidget* dialog);
 
@@ -88,93 +85,85 @@ static GtkResponseType editDlgSettingsAccept (GtkWidget* dialog);
 /* FUNCTION *******************************************************************/
 /** Application settings dialog creation function.
  *
- *  \param pPrefs   Pointer to desktop preferences.
+ *  \param topWidget    Parent widget.
+ *  \param pPrefs       Pointer to desktop preferences.
  *
  *  \return Settings dialog widget pointer.
  ******************************************************************************/
-static GtkWidget* createSettingsDlg (const CFG_DESKTOP* pPrefs)
+static GtkWidget* createSettingsDlg (GtkWidget *topWidget, const CFG_DESKTOP* pPrefs)
 {
     int i;
-    GtkWidget *settingsDlg, *widget, *label, *box, *table, *notebook;
-    GtkObject *spinAdjust;
+    GtkWidget *dialog, *widget, *label, *box, *table, *notebook;
+    GtkAdjustment *spinAdjust;
 
-    settingsDlg = gtk_dialog_new ();
-    gtk_container_set_border_width (GTK_CONTAINER (settingsDlg), 6);
-    gtk_window_set_title (GTK_WINDOW (settingsDlg), _(PACKAGE " Settings"));
-    gtk_window_set_resizable (GTK_WINDOW (settingsDlg), FALSE);
-    gtk_window_set_destroy_with_parent (GTK_WINDOW (settingsDlg), TRUE);
-    gtk_window_set_icon_name (GTK_WINDOW (settingsDlg), GTK_STOCK_PREFERENCES);
-    gtk_window_set_type_hint (GTK_WINDOW (settingsDlg), GDK_WINDOW_TYPE_HINT_DIALOG);
+    dialog = gtk_dialog_new ();
+    gtk_window_set_transient_for (GTK_WINDOW (dialog), GTK_WINDOW (topWidget));
+    gtk_window_set_destroy_with_parent (GTK_WINDOW (dialog), TRUE);
 
-    box = GTK_DIALOG (settingsDlg)->vbox;
+    gtk_container_set_border_width (GTK_CONTAINER (dialog), 6);
+    gtk_window_set_title (GTK_WINDOW (dialog), _(PACKAGE " Settings"));
+    gtk_window_set_resizable (GTK_WINDOW (dialog), FALSE);
+    gtk_window_set_icon_name (GTK_WINDOW (dialog), GUI_ICON_IMAGE_PREFS);
+    gtk_window_set_type_hint (GTK_WINDOW (dialog), GDK_WINDOW_TYPE_HINT_DIALOG);
 
+    box = gtk_dialog_get_content_area (GTK_DIALOG (dialog));
     notebook = gtk_notebook_new ();
     gtk_box_pack_start (GTK_BOX (box), notebook, TRUE, TRUE, 0);
 
-    box = gtk_hbox_new (FALSE, 0);
+    box = gtk_box_new (GTK_ORIENTATION_HORIZONTAL, 0);
     gtk_container_add (GTK_CONTAINER (notebook), box);
 
-    table = gtk_table_new (3, 2, FALSE);
+    table = gtk_grid_new ();                /* gtk_table_new (3, 2, FALSE); */
     gtk_box_pack_start (GTK_BOX (box), table, TRUE, TRUE, 0);
-    gtk_container_set_border_width (GTK_CONTAINER (table), 12);
-    gtk_table_set_row_spacings (GTK_TABLE (table), 6);
-    gtk_table_set_col_spacings (GTK_TABLE (table), 12);
+    gtk_container_set_border_width (GTK_CONTAINER (table), 6);
+    gtk_grid_set_row_spacing (GTK_GRID (table), 6);
+    gtk_grid_set_column_spacing (GTK_GRID (table), 6);
 
     spinAdjust = gtk_adjustment_new (pPrefs->outprec, 1, DBL_DIG, 1, 1, 0);
-    widget = gtk_spin_button_new (GTK_ADJUSTMENT (spinAdjust), 1, 0);
-    gtk_table_attach (GTK_TABLE (table), widget, 1, 2, 0, 1,
-                      (GtkAttachOptions) (GTK_FILL),
-                      (GtkAttachOptions) (0), 0, 0);
+    widget = gtk_spin_button_new (spinAdjust, 1, 0);
+    gtk_grid_attach (GTK_GRID (table), widget, 1, 0, 1, 1);
     gtk_widget_set_tooltip_text (widget, _("The number of digits following the decimal point of a floating point number"));
     gtk_spin_button_set_numeric (GTK_SPIN_BUTTON (widget), TRUE);
     gtk_entry_set_activates_default (GTK_ENTRY (widget), TRUE);
-    GLADE_HOOKUP_OBJECT (settingsDlg, widget, EDITSETDLG_SPIN_PREC);
+    GLADE_HOOKUP_OBJECT (dialog, widget, EDITSETDLG_SPIN_PREC);
 
     label = gtk_label_new_with_mnemonic (_("Output _Precision"));
-    gtk_table_attach (GTK_TABLE (table), label, 0, 1, 0, 1,
-                      (GtkAttachOptions) (GTK_FILL),
-                      (GtkAttachOptions) (0), 0, 0);
-    gtk_misc_set_alignment (GTK_MISC (label), 0, 0.5);
+    gtk_grid_attach (GTK_GRID (table), label, 0, 0, 1, 1);
+    gtk_widget_set_halign (label, GTK_ALIGN_END);
     gtk_label_set_mnemonic_widget (GTK_LABEL (label), widget);
 
     box = gtk_event_box_new ();
-    gtk_table_attach (GTK_TABLE (table), box, 1, 2, 1, 2,
-                      (GtkAttachOptions) (GTK_FILL),
-                      (GtkAttachOptions) (GTK_FILL), 0, 0);
+    gtk_grid_attach (GTK_GRID (table), box, 1, 1, 1, 1);
     gtk_widget_set_tooltip_text (box, _("Frequency unit to be used for in-/output"));
 
-    widget = gtk_combo_box_new_text ();
+    widget = gtk_combo_box_text_new ();
     gtk_container_add (GTK_CONTAINER (box), widget);
-    GLADE_HOOKUP_OBJECT (settingsDlg, widget, EDITSETDLG_COMBO_UNIT_FREQU);
+    GLADE_HOOKUP_OBJECT (dialog, widget, EDITSETDLG_COMBO_UNIT_FREQU);
 
     for (i = 0; i < N_ELEMENTS (unitF); i++)
     {
-        gtk_combo_box_append_text (GTK_COMBO_BOX (widget), unitF[i].name);
+        gtk_combo_box_text_append_text (GTK_COMBO_BOX_TEXT (widget), unitF[i].name);
     } /* for */
 
     gtk_combo_box_set_active (GTK_COMBO_BOX (widget),
                               searchUnit (unitF, N_ELEMENTS (unitF),
                                           pPrefs->frequUnit.name));
     label = gtk_label_new_with_mnemonic (_("_Frequency Unit"));
-    gtk_table_attach (GTK_TABLE (table), label, 0, 1, 1, 2,
-                      (GtkAttachOptions) (GTK_FILL),
-                      (GtkAttachOptions) (0), 0, 0);
-    gtk_misc_set_alignment (GTK_MISC (label), 0, 0.5);
+    gtk_grid_attach (GTK_GRID (table), label, 0, 1, 1, 1);
+    gtk_widget_set_halign (label, GTK_ALIGN_END);
     gtk_label_set_mnemonic_widget (GTK_LABEL (label), widget);
 
     box = gtk_event_box_new ();
-    gtk_table_attach (GTK_TABLE (table), box, 1, 2, 2, 3,
-                      (GtkAttachOptions) (GTK_FILL),
-                      (GtkAttachOptions) (GTK_FILL), 0, 0);
+    gtk_grid_attach (GTK_GRID (table), box, 1, 2, 1, 1);
     gtk_widget_set_tooltip_text (box, _("Time unit to be used for in-/output"));
 
-    widget = gtk_combo_box_new_text ();
+    widget = gtk_combo_box_text_new ();
     gtk_container_add (GTK_CONTAINER (box), widget);
-    GLADE_HOOKUP_OBJECT (settingsDlg, widget, EDITSETDLG_COMBO_UNIT_TIME);
+    GLADE_HOOKUP_OBJECT (dialog, widget, EDITSETDLG_COMBO_UNIT_TIME);
 
     for (i = 0; i < N_ELEMENTS (unitT); i++)
     {
-        gtk_combo_box_append_text (GTK_COMBO_BOX (widget), unitT[i].name);
+        gtk_combo_box_text_append_text (GTK_COMBO_BOX_TEXT (widget), unitT[i].name);
     } /* for */
 
     gtk_combo_box_set_active (GTK_COMBO_BOX (widget), 
@@ -182,10 +171,8 @@ static GtkWidget* createSettingsDlg (const CFG_DESKTOP* pPrefs)
                                           pPrefs->timeUnit.name));
 
     label = gtk_label_new_with_mnemonic (_("_Time Unit"));
-    gtk_table_attach (GTK_TABLE (table), label, 0, 1, 2, 3,
-                      (GtkAttachOptions) (GTK_FILL),
-                      (GtkAttachOptions) (0), 0, 0);
-    gtk_misc_set_alignment (GTK_MISC (label), 0, 0.5);
+    gtk_grid_attach (GTK_GRID (table), label, 0, 2, 1, 1);
+    gtk_widget_set_halign (label, GTK_ALIGN_END);
     gtk_label_set_mnemonic_widget (GTK_LABEL (label), widget);
 
     label = gtk_label_new_with_mnemonic (_("_In-/Output"));
@@ -193,7 +180,7 @@ static GtkWidget* createSettingsDlg (const CFG_DESKTOP* pPrefs)
                                 gtk_notebook_get_nth_page (
                                     GTK_NOTEBOOK (notebook), 0), label);
 
-    box = gtk_vbox_new (FALSE, 0);
+    box = gtk_box_new (GTK_ORIENTATION_VERTICAL, 0);
     gtk_container_add (GTK_CONTAINER (notebook), box);
 
     label = gtk_label_new (_("RFU"));
@@ -201,33 +188,28 @@ static GtkWidget* createSettingsDlg (const CFG_DESKTOP* pPrefs)
                                 gtk_notebook_get_nth_page (
                                     GTK_NOTEBOOK (notebook), 1), label);
 
-    /* Action area
-     */
-    box = GTK_DIALOG (settingsDlg)->action_area;
-    gtk_button_box_set_layout (GTK_BUTTON_BOX (box), GTK_BUTTONBOX_END);
-
-    widget = gtk_button_new_from_stock (GTK_STOCK_HELP);
+    widget = createImageButton (GUI_BUTTON_LABEL_HELP, GUI_BUTTON_IMAGE_HELP);
     gtk_widget_show (widget);
-    gtk_dialog_add_action_widget (GTK_DIALOG (settingsDlg), widget,
+    gtk_dialog_add_action_widget (GTK_DIALOG (dialog), widget,
                                   GTK_RESPONSE_HELP);
 #ifndef TODO
     gtk_widget_set_sensitive (widget, FALSE);
 #endif
-    GTK_WIDGET_SET_FLAGS (widget, GTK_CAN_DEFAULT);
+    gtk_widget_set_can_default (widget, TRUE);
 
-    widget = gtk_button_new_from_stock (GTK_STOCK_CANCEL);
-    gtk_dialog_add_action_widget (GTK_DIALOG (settingsDlg), widget,
+    widget = createImageButton (GUI_BUTTON_LABEL_CANCEL, GUI_BUTTON_IMAGE_CANCEL);
+    gtk_dialog_add_action_widget (GTK_DIALOG (dialog), widget,
                                   GTK_RESPONSE_CANCEL);
-    GTK_WIDGET_SET_FLAGS (widget, GTK_CAN_DEFAULT);
+    gtk_widget_set_can_default (widget, TRUE);
 
-    widget = gtk_button_new_from_stock (GTK_STOCK_OK);
-    gtk_dialog_add_action_widget (GTK_DIALOG (settingsDlg), widget,
+    widget = createImageButton (GUI_BUTTON_LABEL_OK, GUI_BUTTON_IMAGE_OK);
+    gtk_dialog_add_action_widget (GTK_DIALOG (dialog), widget,
                                   GTK_RESPONSE_OK);
-    GTK_WIDGET_SET_FLAGS (widget, GTK_CAN_DEFAULT);
+    gtk_widget_set_can_default (widget, TRUE);
 
-    gtk_widget_show_all (settingsDlg);
+    gtk_widget_show_all (dialog);
 
-    return settingsDlg;
+    return dialog;
 } /* createSettingsDlg() */
 
 
@@ -295,19 +277,22 @@ static GtkResponseType editDlgSettingsAccept (GtkWidget* dialog)
 /* FUNCTION *******************************************************************/
 /** Project info dialog creation function.
  *
- *  \param pInfo    Pointer to current project info (for preset of GtkEntry).
+ *  \param topWidget    Parent widget.
+ *  \param pInfo        Pointer to current project info (for preset of GtkEntry).
  *
- *  \return         Dialog widget pointer.
+ *  \return             Dialog widget pointer.
  ******************************************************************************/
-static GtkWidget* createInfoDlg (const DFCPRJ_INFO *pInfo)
+static GtkWidget* createInfoDlg (GtkWidget *topWidget, const DFCPRJ_INFO *pInfo)
 {
     GtkWidget *dialog, *widget, *entry, *label, *table;
     GdkPixbuf *pixbuf;
 
     dialog = gtk_dialog_new ();
+    gtk_window_set_transient_for (GTK_WINDOW (dialog), GTK_WINDOW (topWidget));
+    gtk_window_set_destroy_with_parent (GTK_WINDOW (dialog), TRUE);
+
     gtk_window_set_title (GTK_WINDOW (dialog), _("Project Info"));
     gtk_window_set_type_hint (GTK_WINDOW (dialog), GDK_WINDOW_TYPE_HINT_DIALOG);
-    gtk_window_set_destroy_with_parent (GTK_WINDOW (dialog), TRUE);
 
     pixbuf = createPixbufFromFile (PACKAGE_ICON);
 
@@ -318,17 +303,17 @@ static GtkWidget* createInfoDlg (const DFCPRJ_INFO *pInfo)
     } /* if */
 
 
-    table = gtk_table_new (3, 2, FALSE);
-    gtk_box_pack_start (GTK_BOX (GTK_DIALOG (dialog)->vbox),
+    table = gtk_grid_new ();                /* gtk_table_new (3, 2, FALSE); */
+    gtk_box_pack_start (GTK_BOX (gtk_dialog_get_content_area (GTK_DIALOG (dialog))),
                         table, TRUE, TRUE, 0);
-    gtk_container_set_border_width (GTK_CONTAINER (table), 12);
-    gtk_table_set_row_spacings (GTK_TABLE (table), 6);
-    gtk_table_set_col_spacings (GTK_TABLE (table), 12);
+    gtk_container_set_border_width (GTK_CONTAINER (table), 6);
+    gtk_grid_set_row_spacing (GTK_GRID (table), 6);
+    gtk_grid_set_column_spacing (GTK_GRID (table), 6);
 
     entry = gtk_entry_new ();                                       /* author */
-    gtk_table_attach (GTK_TABLE (table), entry, 1, 2, 0, 1,
-                      (GtkAttachOptions) (GTK_EXPAND | GTK_FILL),
-                      (GtkAttachOptions) (0), 0, 0);
+    gtk_grid_attach (GTK_GRID (table), entry, 1, 0, 1, 1);
+    gtk_widget_set_halign (entry, GTK_ALIGN_FILL);
+    gtk_widget_set_hexpand (entry, TRUE);
     gtk_widget_set_tooltip_text (entry, _("Author of filter/system"));
     gtk_entry_set_max_length (GTK_ENTRY (entry), 40);
     gtk_entry_set_activates_default (GTK_ENTRY (entry), TRUE);
@@ -339,16 +324,14 @@ static GtkWidget* createInfoDlg (const DFCPRJ_INFO *pInfo)
     GLADE_HOOKUP_OBJECT (dialog, entry, EDITINFODLG_ENTRY_AUTHOR);
 
     label = gtk_label_new_with_mnemonic (_("_Author"));
-    gtk_table_attach (GTK_TABLE (table), label, 0, 1, 0, 1,
-                      (GtkAttachOptions) (GTK_FILL),
-                      (GtkAttachOptions) (0), 0, 0);
-    gtk_misc_set_alignment (GTK_MISC (label), 0, 0.5);
+    gtk_widget_set_halign (label, GTK_ALIGN_END);
     gtk_label_set_mnemonic_widget (GTK_LABEL (label), entry);
+    gtk_grid_attach (GTK_GRID (table), label, 0, 0, 1, 1);
 
     entry = gtk_entry_new ();                                        /* title */
-    gtk_table_attach (GTK_TABLE (table), entry, 1, 2, 1, 2,
-                      (GtkAttachOptions) (GTK_EXPAND | GTK_FILL),
-                      (GtkAttachOptions) (0), 0, 0);
+    gtk_grid_attach (GTK_GRID (table), entry, 1, 1, 1, 1);
+    gtk_widget_set_halign (entry, GTK_ALIGN_FILL);
+    gtk_widget_set_hexpand (entry, TRUE);
     gtk_entry_set_max_length (GTK_ENTRY (entry), 80);
     gtk_entry_set_activates_default (GTK_ENTRY (entry), TRUE);
 
@@ -361,16 +344,16 @@ static GtkWidget* createInfoDlg (const DFCPRJ_INFO *pInfo)
     GLADE_HOOKUP_OBJECT (dialog, entry, EDITINFODLG_ENTRY_TITLE);
 
     label = gtk_label_new_with_mnemonic (_("_Title"));
-    gtk_table_attach (GTK_TABLE (table), label, 0, 1, 1, 2,
-                      (GtkAttachOptions) (GTK_FILL),
-                      (GtkAttachOptions) (0), 0, 0);
-    gtk_misc_set_alignment (GTK_MISC (label), 0, 0.5);
+    gtk_widget_set_halign (label, GTK_ALIGN_END);
     gtk_label_set_mnemonic_widget (GTK_LABEL (label), entry);
+    gtk_grid_attach (GTK_GRID (table), label, 0, 1, 1, 1);
 
     widget = gtk_scrolled_window_new (NULL, NULL);             /* description */
-    gtk_table_attach (GTK_TABLE (table), widget, 1, 2, 2, 3,
-                      (GtkAttachOptions) (GTK_FILL),
-                      (GtkAttachOptions) (GTK_EXPAND | GTK_FILL), 0, 0);
+    gtk_grid_attach (GTK_GRID (table), widget, 1, 2, 1, 1);
+    gtk_widget_set_hexpand (widget, TRUE);
+    gtk_widget_set_halign (widget, GTK_ALIGN_FILL);
+    gtk_widget_set_vexpand (widget, TRUE);
+    gtk_widget_set_valign (widget, GTK_ALIGN_FILL);
     gtk_scrolled_window_set_policy (GTK_SCROLLED_WINDOW (widget), GTK_POLICY_NEVER, GTK_POLICY_ALWAYS);
     gtk_scrolled_window_set_shadow_type (GTK_SCROLLED_WINDOW (widget), GTK_SHADOW_IN);
 
@@ -388,32 +371,24 @@ static GtkWidget* createInfoDlg (const DFCPRJ_INFO *pInfo)
     GLADE_HOOKUP_OBJECT (dialog, entry, EDITINFODLG_TEXTVIEW_DESC);
 
     label = gtk_label_new_with_mnemonic (_("_Description"));
-    gtk_table_attach (GTK_TABLE (table), label, 0, 1, 2, 3,
-                      (GtkAttachOptions) (GTK_FILL),
-                      (GtkAttachOptions) (0), 0, 0);
-    gtk_misc_set_alignment (GTK_MISC (label), 0, 0.5);
+    gtk_widget_set_halign (label, GTK_ALIGN_END);
     gtk_label_set_mnemonic_widget (GTK_LABEL (label), widget);
+    gtk_grid_attach (GTK_GRID (table), label, 0, 2, 1, 1);
 
-
-    /* Action area
-     */
-    gtk_button_box_set_layout (
-        GTK_BUTTON_BOX (GTK_DIALOG (dialog)->action_area), GTK_BUTTONBOX_END);
-
-    widget = gtk_button_new_from_stock (GTK_STOCK_HELP);
+    widget = createImageButton (GUI_BUTTON_LABEL_HELP, GUI_BUTTON_IMAGE_HELP);
     gtk_dialog_add_action_widget (GTK_DIALOG (dialog), widget, GTK_RESPONSE_HELP);
 #ifndef TODO
     gtk_widget_set_sensitive (widget, FALSE);
 #endif
-    GTK_WIDGET_SET_FLAGS (widget, GTK_CAN_DEFAULT);
+    gtk_widget_set_can_default (widget, TRUE);
 
-    widget = gtk_button_new_from_stock (GTK_STOCK_CANCEL);
+    widget = createImageButton (GUI_BUTTON_LABEL_CANCEL, GUI_BUTTON_IMAGE_CANCEL);
     gtk_dialog_add_action_widget (GTK_DIALOG (dialog), widget, GTK_RESPONSE_CANCEL);
-    GTK_WIDGET_SET_FLAGS (widget, GTK_CAN_DEFAULT);
+    gtk_widget_set_can_default (widget, TRUE);
 
-    widget = gtk_button_new_from_stock (GTK_STOCK_OK);
+    widget = createImageButton (GUI_BUTTON_LABEL_OK, GUI_BUTTON_IMAGE_OK);
     gtk_dialog_add_action_widget (GTK_DIALOG (dialog), widget, GTK_RESPONSE_OK);
-    GTK_WIDGET_SET_FLAGS (widget, GTK_CAN_DEFAULT);
+    gtk_widget_set_can_default (widget, TRUE);
 
     gtk_widget_show_all (dialog);
 
@@ -469,8 +444,8 @@ void editDlgSettingsActivate (GtkWidget* widget, gpointer user_data)
 {
     gint result;
 
-    GtkWidget *dialog = createSettingsDlg(cfgGetDesktopPrefs ());
-
+    GtkWidget *dialog = createSettingsDlg (gtk_widget_get_toplevel (widget),
+                                           cfgGetDesktopPrefs ());
     do
     {
         result = gtk_dialog_run (GTK_DIALOG (dialog));
@@ -515,9 +490,8 @@ void editDlgInfoActivate (GtkWidget* widget, gpointer user_data)
     GtkTextIter start, stop;
 
     DFCPRJ_INFO info = {NULL, NULL, NULL};
-    GtkWidget *dialog = createInfoDlg(dfcPrjGetInfo ());
-
-
+    GtkWidget *dialog = createInfoDlg (gtk_widget_get_toplevel (widget),
+                                       dfcPrjGetInfo ());
     do
     {
         result = gtk_dialog_run (GTK_DIALOG (dialog));
