@@ -1,11 +1,8 @@
-/********************* -*- mode: C; coding: utf-8 -*- *************************/
 /**
- * \file
- *           Linear FIR filter coefficients generator.
- *
- * \author   Copyright (C) 2006, 2011, 2012, 2020 Ralf Hoppe
- *
- ******************************************************************************/
+ * \file        linFirFilter.c
+ * \brief       Linear FIR filter coefficients generator.
+ * \copyright   Copyright (C) 2006-2022 Ralf Hoppe <ralf.hoppe@dfcgen.de>
+ */
 
 
 /* INCLUDE FILES **************************************************************/
@@ -179,7 +176,6 @@ static int genCosineSystem (double x, MATHPOLY *poly)
 
     for (i = 0; i <= poly->degree; i++)
     {
-
         tmp = x * (i - deg2);
         poly->coeff[i] = mathTryDiv (cos (4.0 * M_PI * tmp),
                                      1.0 - 64 * tmp * tmp);
@@ -461,6 +457,8 @@ static double firWinVanHann (int step, int degree, double param)
  ******************************************************************************/
 static double firWinBlackman (int step, int degree, double param)
 {
+    (void)param; /* unused */
+
     return mathFuncBlackman ((double) (step + 1) / (degree + 2));
 } /* firWinBlackman() */
 
