@@ -1,13 +1,8 @@
-/********************* -*- mode: C; coding: utf-8 -*- *************************/
 /**
- * \file     mainDlg.c
- * \brief    Main dialog elements (right, bottom of window) handling.
- * \author   Copyright (C) 2006, 2011-2013, 2020 Ralf Hoppe <ralf.hoppe@dfcgen.de>
- *
- * \note     Parts of code taken over from \e glade in interface.c, which itself
- *           isn't a project file.
- *
- ******************************************************************************/
+ * \file        mainDlg.c
+ * \brief       Main dialog elements (right, bottom of window) handling.
+ * \copyright   Copyright (C) 2006-2022 Ralf Hoppe <ralf.hoppe@dfcgen.de>
+ */
 
 
 
@@ -53,8 +48,8 @@ typedef struct
     GtkWidget *btn;             /**< \c GtkButton associated with this action */
     GtkWidget *menu;          /**< \c GtkMenuItem associated with this action */
     MAINDLG_COEFF_OPERATION op;
-    char *text;                    /**< Menuitem text (describing the action) */
-    char *stockimg;
+    char *label;          /**< label text of menuitem (describing the action) */
+    char *stock;                               /**< stock item identification */
     char *tooltip;
 } MAINDLG_COEFF_ACTION;
 
@@ -78,7 +73,7 @@ typedef enum
 
 /* LOCAL FUNCTION DECLARATIONS ************************************************/
 
-static void mainDlgDestroy (GtkObject* object, gpointer user_data);
+static void mainDlgDestroy (GtkWidget* object, gpointer user_data);
 static void mainDlgQuit (GtkWidget* widget, gpointer user_data);
 static BOOL mainDlgCoeffEdit (FLTCOEFF *pFilter, MATHPOLY *poly, int index);
 static BOOL mainDlgCoeffsRound (FLTCOEFF *pFilter, MATHPOLY *poly, int index);
@@ -116,16 +111,22 @@ static GtkWidget *statusbar;      /**< Statusbar in bottom line of top widget */
 static MAINDLG_COEFF_ACTION mainDlgCoeffBtn[] =
 {
     {
-        NULL, NULL, mainDlgCoeffEdit, N_("Change"),
-        GTK_STOCK_EDIT, N_("Edit a single coefficient")
+        .btn = NULL, .menu = NULL, .op = mainDlgCoeffEdit,
+        .label = N_("Change"),
+        .stock = GUI_BUTTON_IMAGE_COEFF_EDIT,
+        .tooltip = N_("Edit a single coefficient")
     },
     {
-        NULL, NULL, mainDlgCoeffsFactor, N_("Multiply"),
-        GTK_STOCK_FULLSCREEN, N_("Multiply all coefficients with a constant")
+        .btn = NULL, .menu = NULL, .op = mainDlgCoeffsFactor,
+        .label = N_("Multiply"),
+        .stock = GUI_BUTTON_IMAGE_COEFF_MULTIPLY,
+        .tooltip = N_("Multiply all coefficients with a constant")
     },
     {
-        NULL, NULL, mainDlgCoeffsRound, N_("Round"),
-        GTK_STOCK_CONVERT, N_("Round all coefficients")
+        .btn = NULL, .menu = NULL, .op = mainDlgCoeffsRound,
+        .label = N_("Round"),
+        .stock = GUI_BUTTON_IMAGE_COEFF_ROUND,
+        .tooltip = N_("Round all coefficients")
     }
 };
 
@@ -141,7 +142,7 @@ static MAINDLG_COEFF_ACTION mainDlgCoeffBtn[] =
  *  \param user_data    User data as passed to function g_signal_connect (unused).
  *
  ******************************************************************************/
-static void mainDlgDestroy (GtkObject* object, gpointer user_data)
+static void mainDlgDestroy (GtkWidget* object, gpointer user_data)
 {
     gtk_main_quit ();
 } /* mainDlgDestroy() */
@@ -278,7 +279,8 @@ static BOOL mainDlgCoeffEdit (FLTCOEFF *pFilter, MATHPOLY *poly, int index)
         g_strdup_printf (_("Changes coefficient of tap z<sup>-%d</sup> in"
                            " the selected list to a new value."), index);
 
-    BOOL ret = dlgPopupDouble (_("Change coefficient"),
+    BOOL ret = dlgPopupDouble (GTK_WINDOW (topWidget),
+                               _("Change coefficient"),
                                _("_New"), intro, poly->coeff + index);
     g_free (intro);
 
@@ -305,7 +307,8 @@ static BOOL mainDlgCoeffsFactor (FLTCOEFF *pFilter, MATHPOLY *poly, int index)
     int i;
     double factor = 1.0;
 
-    BOOL ret = dlgPopupDouble (_("Multiply coefficients"),
+    BOOL ret = dlgPopupDouble (GTK_WINDOW (topWidget),
+                               _("Multiply coefficients"),
                                _("_Factor"),
                                _("Multiplies all coefficients in the"
                                  " selected list with the given factor."),
@@ -567,7 +570,6 @@ static GtkTreeView* coeffCreateListTreeView (GtkTreeView **pOther)
     /* 2nd step: create the tree view
      */
     tree = GTK_TREE_VIEW (gtk_tree_view_new ());
-    gtk_tree_view_set_rules_hint (tree, TRUE);
     gtk_tree_view_set_hover_expand (tree, TRUE);
     gtk_tree_selection_set_mode (gtk_tree_view_get_selection (tree), GTK_SELECTION_SINGLE);
     gtk_tree_view_set_search_column (tree, MAINDLG_LIST_COLUMN_INDEX);
@@ -685,7 +687,6 @@ GtkWidget* mainDlgCreate (void)
     GtkAccelGroup *accel_group = gtk_accel_group_new ();
 
     topWidget = gtk_window_new (GTK_WINDOW_TOPLEVEL);
-    gtk_container_set_border_width (GTK_CONTAINER (topWidget), 6);
 
 #ifndef G_OS_WIN32
     {
@@ -704,10 +705,9 @@ GtkWidget* mainDlgCreate (void)
     gtk_window_set_role (GTK_WINDOW (topWidget), PACKAGE);
 
     g_signal_connect ((gpointer) topWidget, "destroy",
-                      G_CALLBACK (mainDlgDestroy),
-                      NULL);
+                      G_CALLBACK (mainDlgDestroy), NULL);
 
-    vbox1 = gtk_vbox_new (FALSE, 0);
+    vbox1 = gtk_box_new (GTK_ORIENTATION_VERTICAL, 0);
     gtk_container_add (GTK_CONTAINER (topWidget), vbox1);
 
     menuMain = gtk_menu_bar_new ();
@@ -719,26 +719,30 @@ GtkWidget* mainDlgCreate (void)
     menuContainer = gtk_menu_new ();
     gtk_menu_item_set_submenu (GTK_MENU_ITEM (menuMainItem), menuContainer);
 
-    menuItem = gtk_image_menu_item_new_from_stock (GTK_STOCK_NEW, accel_group);
+    menuItem = createImageMenuItem (
+        GUI_MENU_LABEL_NEW, GUI_MENU_IMAGE_NEW, accel_group, GDK_KEY_n);
     gtk_container_add (GTK_CONTAINER (menuContainer), menuItem);
     g_signal_connect ((gpointer) menuItem, "activate",
                       G_CALLBACK (fileDlgNewActivate),
                       NULL);
 
-    menuItem = gtk_image_menu_item_new_from_stock (GTK_STOCK_OPEN, accel_group);
+    menuItem = createImageMenuItem (
+        GUI_MENU_LABEL_OPEN, GUI_MENU_IMAGE_OPEN, accel_group, GDK_KEY_o);
     gtk_container_add (GTK_CONTAINER (menuContainer), menuItem);
     g_signal_connect ((gpointer) menuItem, "activate",
                       G_CALLBACK (fileDlgOpenActivate),
                       NULL);
 
-    menuItem = gtk_image_menu_item_new_from_stock (GTK_STOCK_SAVE, accel_group);
+    menuItem = createImageMenuItem (
+        GUI_MENU_LABEL_SAVE, GUI_MENU_IMAGE_SAVE, accel_group, GDK_KEY_s);
     gtk_container_add (GTK_CONTAINER (menuContainer), menuItem);
     g_signal_connect ((gpointer) menuItem, "activate",
                       G_CALLBACK (fileDlgSaveActivate),
                       NULL);
     GLADE_HOOKUP_OBJECT (topWidget, menuItem, "menuItemFileSave");
 
-    menuItem = gtk_image_menu_item_new_from_stock (GTK_STOCK_SAVE_AS, accel_group);
+    menuItem = createImageMenuItem (
+        GUI_MENU_LABEL_SAVE_AS, GUI_MENU_IMAGE_SAVE_AS, accel_group, GDK_KEY_VoidSymbol);
     gtk_container_add (GTK_CONTAINER (menuContainer), menuItem);
     g_signal_connect ((gpointer) menuItem, "activate",
                       G_CALLBACK (fileDlgSaveAsActivate),
@@ -748,14 +752,16 @@ GtkWidget* mainDlgCreate (void)
     menuItem = gtk_separator_menu_item_new ();             /* separator line */
     gtk_container_add (GTK_CONTAINER (menuContainer), menuItem);
 
-    menuItem = gtk_menu_item_new_with_mnemonic (_("_Export"));
+    menuItem = createImageMenuItem (
+        GUI_MENU_LABEL_EXPORT, GUI_MENU_IMAGE_EXPORT, accel_group, GDK_KEY_e);
     gtk_container_add (GTK_CONTAINER (menuContainer), menuItem);
     g_signal_connect ((gpointer) menuItem, "activate",
                       G_CALLBACK (fileDlgExportActivate),
                       NULL);
     GLADE_HOOKUP_OBJECT (topWidget, menuItem, "menuItemFileExport");
 
-    menuItem = gtk_image_menu_item_new_from_stock (GTK_STOCK_PRINT, accel_group);
+    menuItem = createImageMenuItem (
+        GUI_MENU_LABEL_PRINT, GUI_MENU_IMAGE_PRINT, accel_group, GDK_KEY_p);
     gtk_container_add (GTK_CONTAINER (menuContainer), menuItem);
     g_signal_connect ((gpointer) menuItem, "activate",
                       G_CALLBACK (filterPrintCoeffs),
@@ -766,7 +772,8 @@ GtkWidget* mainDlgCreate (void)
     gtk_container_add (GTK_CONTAINER (menuContainer), widget);
     gtk_widget_set_sensitive (widget, FALSE);
 
-    menuItem = gtk_image_menu_item_new_from_stock (GTK_STOCK_QUIT, accel_group);
+    menuItem = createImageMenuItem (
+        GUI_MENU_LABEL_QUIT, GUI_MENU_IMAGE_QUIT, accel_group, GDK_KEY_q);
     gtk_container_add (GTK_CONTAINER (menuContainer), menuItem);
     g_signal_connect ((gpointer) menuItem, "activate",
                       G_CALLBACK (mainDlgQuit),
@@ -778,10 +785,9 @@ GtkWidget* mainDlgCreate (void)
     menuContainer = gtk_menu_new ();
     gtk_menu_item_set_submenu (GTK_MENU_ITEM (menuMainItem), menuContainer);
 
-    menuItem = gtk_image_menu_item_new_with_mnemonic (_("Project Info"));
+    menuItem = createImageMenuItem (
+        GUI_MENU_LABEL_INFO, GUI_MENU_IMAGE_INFO, accel_group, GDK_KEY_VoidSymbol);
     gtk_container_add (GTK_CONTAINER (menuContainer), menuItem);
-    widget = gtk_image_new_from_stock (GTK_STOCK_INFO, GTK_ICON_SIZE_MENU);
-    gtk_image_menu_item_set_image (GTK_IMAGE_MENU_ITEM (menuItem), widget);
     g_signal_connect ((gpointer) menuItem, "activate",
                       G_CALLBACK (editDlgInfoActivate), NULL);
 
@@ -790,27 +796,24 @@ GtkWidget* mainDlgCreate (void)
     submenuContainer = gtk_menu_new ();
     gtk_menu_item_set_submenu (GTK_MENU_ITEM (widget), submenuContainer);
 
-
     for (i = 0, pAction = mainDlgCoeffBtn;
          i < N_ELEMENTS (mainDlgCoeffBtn);
          i++, pAction++)
     {
-        pAction->menu =
-            gtk_image_menu_item_new_with_mnemonic (gettext (pAction->text));
+        pAction->menu = createImageMenuItem (
+            gettext (pAction->label), pAction->stock, accel_group, GDK_KEY_VoidSymbol);
         gtk_container_add (GTK_CONTAINER (submenuContainer), pAction->menu);
-        widget = gtk_image_new_from_stock (pAction->stockimg, GTK_ICON_SIZE_MENU);
-        gtk_image_menu_item_set_image (GTK_IMAGE_MENU_ITEM (pAction->menu), widget);
         gtk_widget_set_sensitive (GTK_WIDGET(pAction->menu), FALSE);
         g_signal_connect ((gpointer) pAction->menu, "activate",
                           G_CALLBACK (mainDlgCoeffAction), pAction);
     } /* for */
 
-
     widget = gtk_separator_menu_item_new ();
     gtk_container_add (GTK_CONTAINER (menuContainer), widget);
     gtk_widget_set_sensitive (widget, FALSE);
 
-    menuItem = gtk_image_menu_item_new_from_stock (GTK_STOCK_PREFERENCES, accel_group);
+    menuItem = createImageMenuItem (GUI_MENU_LABEL_PREFS, GUI_MENU_IMAGE_PREFS,
+                                    accel_group, GDK_KEY_VoidSymbol);
     gtk_container_add (GTK_CONTAINER (menuContainer), menuItem);
     g_signal_connect ((gpointer) menuItem, "activate",
                       G_CALLBACK (editDlgSettingsActivate), NULL);
@@ -869,18 +872,20 @@ GtkWidget* mainDlgCreate (void)
                       G_CALLBACK (responseWinMenuActivate),
                       GINT_TO_POINTER (RESPONSE_TYPE_STEP));
 
-    menuMainItem = gtk_menu_item_new_with_mnemonic (_("_Help"));
+    menuMainItem = gtk_menu_item_new_with_mnemonic (GUI_MENU_LABEL_HELP);
     gtk_container_add (GTK_CONTAINER (menuMain), menuMainItem);
 
     menuContainer = gtk_menu_new ();
     gtk_menu_item_set_submenu (GTK_MENU_ITEM (menuMainItem), menuContainer);
 
 #ifdef TODO
-    menuItem = gtk_image_menu_item_new_from_stock (GTK_STOCK_HELP, accel_group);
+    menuItem = createImageMenuItem (
+        GUI_MENU_LABEL_HELP, GUI_MENU_IMAGE_HELP, accel_group, GDK_KEY_h);
     gtk_container_add (GTK_CONTAINER (menuContainer), menuItem);
 #endif
 
-    menuItem = gtk_image_menu_item_new_from_stock (GTK_STOCK_ABOUT, accel_group);
+    menuItem = createImageMenuItem (
+        GUI_MENU_LABEL_ABOUT, GUI_MENU_IMAGE_ABOUT, accel_group, GDK_KEY_VoidSymbol);
     gtk_container_add (GTK_CONTAINER (menuContainer), menuItem);
     g_signal_connect ((gpointer) menuItem, "activate",
                       G_CALLBACK (helpDlgMenuActivate),
@@ -893,20 +898,32 @@ GtkWidget* mainDlgCreate (void)
     widget = (GtkWidget*) gtk_tool_item_new ();
     gtk_container_add (GTK_CONTAINER (toolbarMain), widget);
 
-    button = (GtkWidget*) gtk_tool_button_new_from_stock (GTK_STOCK_OPEN);
+    button = (GtkWidget*) gtk_tool_button_new (
+        gtk_image_new_from_icon_name (GUI_MENU_IMAGE_OPEN,
+                                      GTK_ICON_SIZE_LARGE_TOOLBAR),
+        GUI_MENU_LABEL_OPEN);
+    gtk_tool_button_set_use_underline (GTK_TOOL_BUTTON (button), TRUE);
     gtk_container_add (GTK_CONTAINER (toolbarMain), button);
     g_signal_connect ((gpointer) button, "clicked",
                       G_CALLBACK (fileDlgOpenActivate),
                       NULL);
 
-    button = (GtkWidget*) gtk_tool_button_new_from_stock (GTK_STOCK_SAVE);
+    button = (GtkWidget*) gtk_tool_button_new (
+        gtk_image_new_from_icon_name (GUI_MENU_IMAGE_SAVE,
+                                      GTK_ICON_SIZE_LARGE_TOOLBAR),
+        GUI_MENU_LABEL_SAVE);
+    gtk_tool_button_set_use_underline (GTK_TOOL_BUTTON (button), TRUE);
     gtk_container_add (GTK_CONTAINER (toolbarMain), button);
     g_signal_connect ((gpointer) button, "clicked",
                       G_CALLBACK (fileDlgSaveActivate),
                       NULL);
     GLADE_HOOKUP_OBJECT (topWidget, button, "toolBtnSave");
 
-    button = (GtkWidget*) gtk_tool_button_new_from_stock (GTK_STOCK_NEW);
+    button = (GtkWidget*) gtk_tool_button_new (
+        gtk_image_new_from_icon_name (GUI_MENU_IMAGE_NEW,
+                                      GTK_ICON_SIZE_LARGE_TOOLBAR),
+        GUI_MENU_LABEL_NEW);
+    gtk_tool_button_set_use_underline (GTK_TOOL_BUTTON (button), TRUE);
     gtk_container_add (GTK_CONTAINER (toolbarMain), button);
     g_signal_connect ((gpointer) button, "clicked",
                       G_CALLBACK (fileDlgNewActivate), NULL);
@@ -914,7 +931,11 @@ GtkWidget* mainDlgCreate (void)
     widget = (GtkWidget*) gtk_separator_tool_item_new ();
     gtk_container_add (GTK_CONTAINER (toolbarMain), widget);
 
-    button = (GtkWidget*) gtk_tool_button_new_from_stock (GTK_STOCK_PREFERENCES);
+    button = (GtkWidget*) gtk_tool_button_new (
+        gtk_image_new_from_icon_name (GUI_MENU_IMAGE_PREFS,
+                                      GTK_ICON_SIZE_LARGE_TOOLBAR),
+        GUI_MENU_LABEL_PREFS);
+    gtk_tool_button_set_use_underline (GTK_TOOL_BUTTON (button), TRUE);
     gtk_container_add (GTK_CONTAINER (toolbarMain), button);
     g_signal_connect ((gpointer) button, "clicked",
                       G_CALLBACK (editDlgSettingsActivate), NULL);
@@ -922,19 +943,23 @@ GtkWidget* mainDlgCreate (void)
     widget = (GtkWidget*) gtk_separator_tool_item_new ();
     gtk_container_add (GTK_CONTAINER (toolbarMain), widget);
 
-    button = (GtkWidget*) gtk_tool_button_new_from_stock (GTK_STOCK_QUIT);
+    button = (GtkWidget*) gtk_tool_button_new (
+        gtk_image_new_from_icon_name (GUI_MENU_IMAGE_QUIT,
+                                      GTK_ICON_SIZE_LARGE_TOOLBAR),
+        GUI_MENU_LABEL_QUIT);
+    gtk_tool_button_set_use_underline (GTK_TOOL_BUTTON (button), TRUE);
     gtk_container_add (GTK_CONTAINER (toolbarMain), button);
     g_signal_connect ((gpointer) button, "clicked", G_CALLBACK (mainDlgQuit), NULL);
 
-    hbox1 = gtk_hbox_new (FALSE, 0);
+    hbox1 = gtk_box_new (GTK_ORIENTATION_HORIZONTAL, 0);
     gtk_box_pack_start (GTK_BOX (vbox1), hbox1, TRUE, TRUE, 0);
     gtk_container_set_border_width (GTK_CONTAINER (hbox1), 6);
 
-    boxDesignDlg = gtk_vbox_new (FALSE, 12);
-    gtk_box_pack_start (GTK_BOX (hbox1), boxDesignDlg, FALSE, TRUE, 0);
+    boxDesignDlg = gtk_box_new (GTK_ORIENTATION_VERTICAL, 6);
+    gtk_box_pack_start (GTK_BOX (hbox1), boxDesignDlg, FALSE, FALSE, 0);
     gtk_container_set_border_width (GTK_CONTAINER (boxDesignDlg), 6);
 
-    hbox3 = gtk_hbox_new (FALSE, 12);
+    hbox3 = gtk_box_new (GTK_ORIENTATION_HORIZONTAL, 6);
     gtk_box_pack_start (GTK_BOX (boxDesignDlg), hbox3, FALSE, FALSE, 0);
     gtk_container_set_border_width (GTK_CONTAINER (hbox3), 6);
 
@@ -943,44 +968,45 @@ GtkWidget* mainDlgCreate (void)
     gtk_box_pack_start (GTK_BOX (hbox3), label, FALSE, FALSE, 0);
 
     widget = gtk_event_box_new ();
-    gtk_box_pack_start (GTK_BOX (hbox3), widget, FALSE, TRUE, 0);
+    gtk_box_pack_start (GTK_BOX (hbox3), widget, FALSE, FALSE, 0);
     gtk_widget_set_tooltip_text (widget, _("Class of filter (or system)"));
 
-    comboFilterClass = gtk_combo_box_new_text ();
+    comboFilterClass = gtk_combo_box_text_new ();
     gtk_container_add (GTK_CONTAINER (widget), comboFilterClass);
     gtk_label_set_mnemonic_widget (GTK_LABEL (label), comboFilterClass);
 
-    widget = gtk_hbutton_box_new ();
-    gtk_box_pack_start (GTK_BOX (boxDesignDlg), widget, FALSE, TRUE, 0);
+    widget = gtk_button_box_new (GTK_ORIENTATION_HORIZONTAL);
+    gtk_widget_set_valign (widget, GTK_ALIGN_END);
+    gtk_box_pack_start (GTK_BOX (boxDesignDlg), widget, TRUE, TRUE, 0);
     gtk_container_set_border_width (GTK_CONTAINER (widget), 6);
     gtk_button_box_set_layout (GTK_BUTTON_BOX (widget), GTK_BUTTONBOX_SPREAD);
-    gtk_box_set_spacing (GTK_BOX (widget), 12);
+    gtk_box_set_spacing (GTK_BOX (widget), 16);
 
-    button = gtk_button_new_from_stock (GTK_STOCK_HELP);
+    button = createImageButton (GUI_BUTTON_LABEL_HELP, GUI_BUTTON_IMAGE_HELP);
     gtk_container_add (GTK_CONTAINER (widget), button);
     gtk_widget_set_tooltip_text (button, _("Help"));
 #ifndef TODO
     gtk_widget_set_sensitive (button, FALSE);
 #endif
 
-    button = gtk_button_new_from_stock (GTK_STOCK_APPLY);
+    button = createImageButton (GUI_BUTTON_LABEL_APPLY, GUI_BUTTON_IMAGE_APPLY);
     gtk_container_add (GTK_CONTAINER (widget), button);
-    GTK_WIDGET_SET_FLAGS (button, GTK_CAN_DEFAULT);
+    gtk_widget_set_can_default (button, TRUE);
     g_signal_connect ((gpointer) button, "clicked",
                       G_CALLBACK (designDlgApply), comboFilterClass);
     gtk_widget_set_tooltip_text (button, _("Apply input data"));
     GLADE_HOOKUP_OBJECT (topWidget, button, MAINDLG_BTN_APPLY);
 
-    boxFilterDlg = gtk_vbox_new (FALSE, 0);
+    boxFilterDlg = gtk_box_new (GTK_ORIENTATION_VERTICAL, 0);
     gtk_box_pack_start (GTK_BOX (hbox1), boxFilterDlg, TRUE, TRUE, 0);
     gtk_container_set_border_width (GTK_CONTAINER (boxFilterDlg), 6);
 
-    vpaneFilter = gtk_vpaned_new ();
+    vpaneFilter = gtk_paned_new (GTK_ORIENTATION_VERTICAL);
     gtk_box_pack_start (GTK_BOX (boxFilterDlg), vpaneFilter, TRUE, TRUE, 0);
     gtk_container_set_border_width (GTK_CONTAINER (vpaneFilter), 6);
 
     widget = gtk_frame_new (NULL);
-    gtk_paned_pack1 (GTK_PANED (vpaneFilter), widget, FALSE, TRUE);
+    gtk_paned_pack1 (GTK_PANED (vpaneFilter), widget, FALSE, FALSE);
     gtk_container_set_border_width (GTK_CONTAINER (widget), 6);
 
     gtk_container_add (GTK_CONTAINER (widget), rootsPlotCreate ());
@@ -989,15 +1015,18 @@ GtkWidget* mainDlgCreate (void)
     gtk_frame_set_label_widget (GTK_FRAME (widget), label);
     gtk_label_set_use_markup (GTK_LABEL (label), TRUE);
 
-    table = gtk_table_new (2, 2, FALSE);
+    table = gtk_grid_new ();                /* gtk_table_new (2, 2, FALSE); */
     gtk_paned_pack2 (GTK_PANED (vpaneFilter), table, TRUE, TRUE);
     gtk_container_set_border_width (GTK_CONTAINER (table), 6);
-    gtk_table_set_col_spacings (GTK_TABLE (table), 12);
+    gtk_grid_set_column_spacing (GTK_GRID (table), 16);
+    gtk_grid_set_column_homogeneous (GTK_GRID (table), TRUE);
 
     widget = gtk_scrolled_window_new (NULL, NULL);
-    gtk_table_attach (GTK_TABLE (table), widget, 1, 2, 1, 2,
-                      (GtkAttachOptions) (GTK_EXPAND | GTK_SHRINK | GTK_FILL),
-                      (GtkAttachOptions) (GTK_EXPAND | GTK_SHRINK | GTK_FILL), 0, 0);
+    gtk_grid_attach (GTK_GRID (table), widget, 1, 1, 1, 1);
+    gtk_widget_set_halign (widget, GTK_ALIGN_FILL);
+    gtk_widget_set_hexpand (widget, TRUE);
+    gtk_widget_set_valign (widget, GTK_ALIGN_FILL);
+    gtk_widget_set_vexpand (widget, TRUE);
     gtk_scrolled_window_set_policy (GTK_SCROLLED_WINDOW (widget), GTK_POLICY_AUTOMATIC, GTK_POLICY_AUTOMATIC);
     gtk_scrolled_window_set_shadow_type (GTK_SCROLLED_WINDOW (widget), GTK_SHADOW_IN);
 
@@ -1006,9 +1035,11 @@ GtkWidget* mainDlgCreate (void)
     gtk_widget_set_tooltip_text (GTK_WIDGET (treeDenominator), _("Denominator coefficients"));
 
     widget = gtk_scrolled_window_new (NULL, NULL);
-    gtk_table_attach (GTK_TABLE (table), widget, 0, 1, 1, 2,
-                      (GtkAttachOptions) (GTK_EXPAND | GTK_SHRINK | GTK_FILL),
-                      (GtkAttachOptions) (GTK_EXPAND | GTK_SHRINK | GTK_FILL), 0, 0);
+    gtk_grid_attach (GTK_GRID (table), widget, 0, 1, 1, 1);
+    gtk_widget_set_halign (widget, GTK_ALIGN_FILL);
+    gtk_widget_set_hexpand (widget, TRUE);
+    gtk_widget_set_valign (widget, GTK_ALIGN_FILL);
+    gtk_widget_set_vexpand (widget, TRUE);
     gtk_scrolled_window_set_policy (GTK_SCROLLED_WINDOW (widget), GTK_POLICY_AUTOMATIC, GTK_POLICY_AUTOMATIC);
     gtk_scrolled_window_set_shadow_type (GTK_SCROLLED_WINDOW (widget), GTK_SHADOW_IN);
 
@@ -1017,23 +1048,19 @@ GtkWidget* mainDlgCreate (void)
     gtk_widget_set_tooltip_text (GTK_WIDGET (treeNumerator), _("Numerator coefficients"));
 
     label = gtk_label_new (_("<b>Numerator</b>"));
-    gtk_table_attach (GTK_TABLE (table), label, 0, 1, 0, 1,
-                      (GtkAttachOptions) (GTK_FILL),
-                      (GtkAttachOptions) (0), 0, 6);
+    gtk_grid_attach (GTK_GRID (table), label, 0, 0, 1, 1);
+    gtk_widget_set_halign (label, GTK_ALIGN_FILL);
     gtk_label_set_use_markup (GTK_LABEL (label), TRUE);
-    gtk_misc_set_alignment (GTK_MISC (label), 0, 0.5);
     gtk_label_set_ellipsize (GTK_LABEL (label), PANGO_ELLIPSIZE_END);
 
     label = gtk_label_new (_("<b>Denominator</b>"));
-    gtk_table_attach (GTK_TABLE (table), label, 1, 2, 0, 1,
-                      (GtkAttachOptions) (GTK_FILL),
-                      (GtkAttachOptions) (0), 0, 6);
+    gtk_grid_attach (GTK_GRID (table), label, 1, 0, 1, 1);
+    gtk_widget_set_halign (widget, GTK_ALIGN_FILL);
     gtk_label_set_use_markup (GTK_LABEL (label), TRUE);
-    gtk_misc_set_alignment (GTK_MISC (label), 0, 0.5);
     gtk_label_set_ellipsize (GTK_LABEL (label), PANGO_ELLIPSIZE_END);
 
-    hbox2 = gtk_hbutton_box_new ();
-    gtk_box_pack_start (GTK_BOX (boxFilterDlg), hbox2, FALSE, TRUE, 0);
+    hbox2 = gtk_button_box_new (GTK_ORIENTATION_HORIZONTAL);
+    gtk_box_pack_start (GTK_BOX (boxFilterDlg), hbox2, FALSE, FALSE, 0);
     gtk_container_set_border_width (GTK_CONTAINER (hbox2), 6);
     gtk_box_set_spacing (GTK_BOX (hbox2), 6);
 
@@ -1041,18 +1068,18 @@ GtkWidget* mainDlgCreate (void)
          i < N_ELEMENTS (mainDlgCoeffBtn);
          i++, pAction++)
     {
-        pAction->btn = gtk_button_new ();
+        pAction->btn = createImageButton (gettext (pAction->label),
+                                          pAction->stock);
         gtk_container_add (GTK_CONTAINER (hbox2), pAction->btn);
         gtk_widget_set_sensitive (pAction->btn, FALSE);
         gtk_widget_set_tooltip_text (pAction->btn, gettext (pAction->tooltip));
-        widget = gtk_image_new_from_stock (pAction->stockimg,
-                                           GTK_ICON_SIZE_BUTTON);
-        gtk_container_add (GTK_CONTAINER (pAction->btn), widget);
+
         g_signal_connect ((gpointer) pAction->btn, "clicked",
                           G_CALLBACK (mainDlgCoeffAction), pAction);
     } /* for */
 
-
+    widget = gtk_separator_new (GTK_ORIENTATION_HORIZONTAL);
+    gtk_box_pack_start (GTK_BOX (vbox1), widget, FALSE, FALSE, 0);
     statusbar = gtk_statusbar_new ();
     gtk_box_pack_start (GTK_BOX (vbox1), statusbar, FALSE, FALSE, 0);
 
@@ -1074,8 +1101,8 @@ GtkWidget* mainDlgCreate (void)
 
     mainDlgUpdateAll (NULL);                             /* set initial state */
 
-    gtk_widget_size_request (boxDesignDlg, &size);
-    gtk_paned_set_position (GTK_PANED (vpaneFilter), size.height / 3);
+    gtk_widget_get_preferred_size (boxDesignDlg, NULL, &size);
+    gtk_paned_set_position (GTK_PANED (vpaneFilter), size.height / 2);
 
     return topWidget;
 } /* mainDlgCreate() */
@@ -1152,7 +1179,7 @@ void mainDlgUpdatePrjInfo ()
  ******************************************************************************/
 BOOL mainDlgUpdateFilter (int err)
 {
-    FLTCOEFF* pFilter = dfcPrjGetFilter();
+    FLTCOEFF* pFilter = dfcPrjGetFilter ();
     BOOL valid = pFilter != NULL;
 
     if (!FLTERR_CRITICAL (err))
@@ -1198,6 +1225,7 @@ BOOL mainDlgUpdateFilter (int err)
 void mainDlgRedrawAll ()
 {
     responseWinRedraw (RESPONSE_TYPE_SIZE);     /* redraw all response plots */
+    designDlgUpdate (topWidget);                     /* redraw design dialog */
     rootsPlotRedraw ();                /* redraw roots window in main dialog */
     coeffRedrawListTreeViews (); /* redraw coefficients lists in main dialog */
 }
