@@ -1,13 +1,9 @@
-/********************* -*- mode: C; coding: utf-8 -*- *************************/
 /**
- * \file     miscDesignDlg.c
- * \brief    Miscellaneous FIR/IIR design dialogs.
- *
- * \note     Includes raw filters (filters without a design).
- *
- * \author   Copyright (C) 2006, 2011, 2012, 2020 Ralf Hoppe <ralf.hoppe@dfcgen.de>
- *
- ******************************************************************************/
+ * \file        miscDesignDlg.c
+ * \brief       Miscellaneous FIR/IIR design dialogs.
+ * \note        Includes raw filters (filters without a design).
+ * \copyright   Copyright (C) 2006-2022 Ralf Hoppe <ralf.hoppe@dfcgen.de>
+ */
 
 
 /* INCLUDE FILES **************************************************************/
@@ -45,7 +41,7 @@ typedef struct
 #define MISCDLG_SPIN_DEGREE     "spinDegree" /**< Degree of filter entry/spin */
 #define MISCDLG_COMBO_TYPE      "comboType"      /**< Type of filter combobox */
 #define MISCDLG_LABEL_DESC      "labelDesc"        /**< Description of filter */
-#define MISCDLG_EXPANDER_DESC   "expanderDesc"           /**< Expander widget */
+#define MISCDLG_FRAME_DESC      "frameDesc"     /**< Description frame widget */
 #define MISCDLG_UNIT_SAMPLE     "unitSampleF" /**< Sample frequency unit label */
 
 
@@ -115,30 +111,27 @@ static GtkWidget* createDialog (GtkWidget *topWidget, GtkWidget *boxDesignDlg,
                                 const CFG_DESKTOP* pPrefs)
 {
     GtkWidget *miscDesignDlgMain, *miscDesignDlgTable;
-    GtkWidget *label, *expander, *combo, *widget;
-    GtkObject *spinAdjustment;
+    GtkWidget *label, *combo, *frame, *widget;
+    GtkAdjustment *spinAdjust;
 
     miscDesignDlgMain = gtk_frame_new (NULL);             /* create the frame */
-    gtk_box_pack_start (GTK_BOX (boxDesignDlg), miscDesignDlgMain, TRUE, TRUE, 0);
+    gtk_widget_set_valign (miscDesignDlgMain, GTK_ALIGN_START);
+    gtk_box_pack_start (GTK_BOX (boxDesignDlg), miscDesignDlgMain, FALSE, FALSE, 0);
     gtk_container_set_border_width (GTK_CONTAINER (miscDesignDlgMain), 6);
     gtk_frame_set_shadow_type (GTK_FRAME (miscDesignDlgMain), GTK_SHADOW_NONE);
     gtk_box_reorder_child (GTK_BOX (boxDesignDlg), miscDesignDlgMain, 1);
     GLADE_HOOKUP_OBJECT (topWidget, miscDesignDlgMain, MISCDLG_WIDGET_MAIN);
 
-    widget = gtk_alignment_new (0.5, 0.5, 1, 1);
-    gtk_container_add (GTK_CONTAINER (miscDesignDlgMain), widget);
-    gtk_alignment_set_padding (GTK_ALIGNMENT (widget), 0, 0, 12, 0); /* indent childs */
-
-    miscDesignDlgTable = gtk_table_new (4, 3, FALSE);
-    gtk_container_add (GTK_CONTAINER (widget), miscDesignDlgTable);
+    miscDesignDlgTable = gtk_grid_new ();   /* gtk_table_new (4, 3, FALSE); */
+    gtk_container_add (GTK_CONTAINER (miscDesignDlgMain), miscDesignDlgTable);
     gtk_container_set_border_width (GTK_CONTAINER (miscDesignDlgTable), 6);
-    gtk_table_set_row_spacings (GTK_TABLE (miscDesignDlgTable), 6);
-    gtk_table_set_col_spacings (GTK_TABLE (miscDesignDlgTable), 6);
+    gtk_widget_set_margin_start (miscDesignDlgTable, GUI_INDENT_CHILD_PIXEL);
+    gtk_grid_set_row_spacing (GTK_GRID (miscDesignDlgTable), 6);
+    gtk_grid_set_column_spacing (GTK_GRID (miscDesignDlgTable), 6);
+
+    combo = gtk_combo_box_text_new ();           /* type of filter combobox */
+    gtk_grid_attach (GTK_GRID (miscDesignDlgTable), combo, 0, 0, 3, 1);
 
-    combo = gtk_combo_box_new_text ();             /* type of filter combobox */
-    gtk_table_attach (GTK_TABLE (miscDesignDlgTable), combo, 0, 3, 0, 1,
-                      (GtkAttachOptions) (GTK_FILL),
-                      (GtkAttachOptions) (0), 0, 6);
     g_signal_connect_after ((gpointer) combo, "changed",
                             G_CALLBACK (miscDlgOnTypeComboChanged),
                             NULL);
@@ -150,66 +143,58 @@ static GtkWidget* createDialog (GtkWidget *topWidget, GtkWidget *boxDesignDlg,
     gtk_label_set_mnemonic_widget (GTK_LABEL (label), combo);
 
     label = gtk_label_new_with_mnemonic (_("f<sub>_Sample</sub>"));
-    gtk_table_attach (GTK_TABLE (miscDesignDlgTable), label, 0, 1, 2, 3,
-                      (GtkAttachOptions) (GTK_FILL),
-                      (GtkAttachOptions) (0), 3, 0);
+    gtk_grid_attach (GTK_GRID (miscDesignDlgTable), label, 0, 2, 1, 1);
+    gtk_widget_set_halign (label, GTK_ALIGN_END);
     gtk_label_set_use_markup (GTK_LABEL (label), TRUE);
-    gtk_misc_set_alignment (GTK_MISC (label), 0, 0.5);
 
     widget = gtk_entry_new ();
     gtk_entry_set_activates_default (GTK_ENTRY (widget), TRUE);
-    gtk_table_attach (GTK_TABLE (miscDesignDlgTable), widget, 1, 2, 2, 3,
-                      (GtkAttachOptions) (GTK_FILL),
-                      (GtkAttachOptions) (0), 0, 0);
+    gtk_grid_attach (GTK_GRID (miscDesignDlgTable), widget, 1, 2, 1, 1);
     gtk_widget_set_tooltip_text (widget, _("Sample frequency"));
     gtk_entry_set_width_chars (GTK_ENTRY (widget), GUI_ENTRY_WIDTH_CHARS);
     gtk_label_set_mnemonic_widget (GTK_LABEL (label), widget);
     GLADE_HOOKUP_OBJECT (topWidget, widget, MISCDLG_ENTRY_SAMPLE);
 
     label = gtk_label_new (pPrefs->frequUnit.name);  /* sample frequency unit */
-    gtk_table_attach (GTK_TABLE (miscDesignDlgTable), label, 2, 3, 2, 3,
-                      (GtkAttachOptions) (GTK_FILL),
-                      (GtkAttachOptions) (0), 0, 0);
-    gtk_misc_set_alignment (GTK_MISC (label), 0, 0.5);
+    gtk_grid_attach (GTK_GRID (miscDesignDlgTable), label, 2, 2, 1, 1);
+    gtk_widget_set_halign (label, GTK_ALIGN_START);
     GLADE_HOOKUP_OBJECT (topWidget, label, MISCDLG_UNIT_SAMPLE);
 
     label = gtk_label_new_with_mnemonic (_("_Degree"));
-    gtk_table_attach (GTK_TABLE (miscDesignDlgTable), label, 0, 1, 1, 2,
-                      (GtkAttachOptions) (GTK_FILL),
-                      (GtkAttachOptions) (0), 0, 0);
-    gtk_misc_set_alignment (GTK_MISC (label), 0, 0.5);
+    gtk_grid_attach (GTK_GRID (miscDesignDlgTable), label, 0, 1, 1, 1);
+    gtk_widget_set_halign (label, GTK_ALIGN_END);
 
-    spinAdjustment = gtk_adjustment_new (1, FLT_DEGREE_MIN, FLT_DEGREE_MAX, 1, 10, 0);
-    widget = gtk_spin_button_new (GTK_ADJUSTMENT (spinAdjustment), 1, 0);
+    spinAdjust = gtk_adjustment_new (1, FLT_DEGREE_MIN, FLT_DEGREE_MAX, 1, 10, 0);
+    widget = gtk_spin_button_new (spinAdjust, 1, 0);
     gtk_entry_set_activates_default (GTK_ENTRY (widget), TRUE);
-    gtk_table_attach (GTK_TABLE (miscDesignDlgTable), widget, 1, 2, 1, 2,
-                      (GtkAttachOptions) (GTK_FILL),
-                      (GtkAttachOptions) (0), 0, 0);
+    gtk_grid_attach (GTK_GRID (miscDesignDlgTable), widget, 1, 1, 1, 1);
     gtk_widget_set_tooltip_text (widget, _("Degree of system"));
     gtk_spin_button_set_numeric (GTK_SPIN_BUTTON (widget), TRUE);
     gtk_label_set_mnemonic_widget (GTK_LABEL (label), widget);
     GLADE_HOOKUP_OBJECT (topWidget, widget, MISCDLG_SPIN_DEGREE);
 
-    expander = gtk_expander_new (NULL);
-    gtk_table_attach (GTK_TABLE (miscDesignDlgTable), expander, 0, 3, 3, 4,
-                      (GtkAttachOptions) (GTK_SHRINK | GTK_FILL),
-                      (GtkAttachOptions) (GTK_SHRINK | GTK_FILL), 0, 12);
-    gtk_expander_set_expanded (GTK_EXPANDER (expander), TRUE);
-    gtk_expander_set_spacing (GTK_EXPANDER (expander), 12);
-    GLADE_HOOKUP_OBJECT (topWidget, expander, MISCDLG_EXPANDER_DESC);
+    widget = gtk_label_new ("");   /* simulate an empty row with this label */
+    gtk_grid_attach (GTK_GRID (miscDesignDlgTable), widget, 0, 3, 3, 1);
+
+    frame = gtk_frame_new (NULL);
+    gtk_frame_set_shadow_type (GTK_FRAME (frame), GTK_SHADOW_NONE);
+    gtk_grid_attach (GTK_GRID (miscDesignDlgTable), frame, 0, 4, 3, 1);
+    GLADE_HOOKUP_OBJECT (topWidget, frame, MISCDLG_FRAME_DESC);
+
+    label = gtk_label_new (_("<i>Description</i>:"));
+    gtk_frame_set_label_widget (GTK_FRAME (frame), label);
+    gtk_label_set_use_markup (GTK_LABEL (label), TRUE);
 
     label = gtk_label_new ("");                      /* filter description text */
     gtk_label_set_use_markup (GTK_LABEL (label), TRUE);
     gtk_label_set_line_wrap (GTK_LABEL (label), TRUE);
     gtk_label_set_selectable (GTK_LABEL (label), TRUE);
-    gtk_misc_set_alignment (GTK_MISC (label), 0, 0);
-    gtk_container_add (GTK_CONTAINER (expander), label);
+    gtk_label_set_max_width_chars (GTK_LABEL (label), GUI_LABEL_WRAP_CHARS);
+    gtk_widget_set_margin_start (label, GUI_INDENT_CHILD_PIXEL);
+    gtk_widget_set_margin_top (label, 6);
+    gtk_container_add (GTK_CONTAINER (frame), label);
     GLADE_HOOKUP_OBJECT (topWidget, label, MISCDLG_LABEL_DESC);
 
-    label = gtk_label_new (_("<i>Description</i>"));
-    gtk_label_set_use_markup (GTK_LABEL (label), TRUE);
-    gtk_expander_set_label_widget (GTK_EXPANDER (expander), label);
-
     gtk_widget_show_all (miscDesignDlgMain);
 
     return combo;
@@ -255,7 +240,7 @@ static void updateLayout (GtkWidget *topWidget, GtkWidget *combo, int index)
         gtk_widget_set_sensitive (widget, FALSE);
     } /* else */
 
-    widget = lookup_widget (topWidget, MISCDLG_EXPANDER_DESC);
+    widget = lookup_widget (topWidget, MISCDLG_FRAME_DESC);
 
     if ((desc != NULL) && (g_utf8_strlen (desc, -1) > 0)) /* show description if available */
     {
@@ -265,7 +250,7 @@ static void updateLayout (GtkWidget *topWidget, GtkWidget *combo, int index)
     } /* if */
     else
     {
-        gtk_widget_hide_all (widget);
+        gtk_widget_hide (widget);
     } /* else */
 
 } /* updateLayout() */
@@ -345,14 +330,15 @@ void miscDesignDlgCreate (GtkWidget *topWidget, GtkWidget *boxDesignDlg,
 
     /* 1st step: create dialog layout
      */
-    GtkComboBox* combo = GTK_COMBO_BOX (createDialog (topWidget, boxDesignDlg, pPrefs));
+    GtkWidget* combo = createDialog (topWidget, boxDesignDlg, pPrefs);
 
 
     /* 2nd step: insert misc filters
      */
     for (count = 0; count < MISCFLT_SIZE; count++)
     {
-        gtk_combo_box_append_text (combo, gettext (miscFilterList[count].title));
+        gtk_combo_box_text_append_text (GTK_COMBO_BOX_TEXT (combo),
+                                        gettext (miscFilterList[count].title));
     } /* for */
 
 
@@ -365,7 +351,7 @@ void miscDesignDlgCreate (GtkWidget *topWidget, GtkWidget *boxDesignDlg,
 
     if (err == NULL)                                             /* no error? */
     {
-        gtk_combo_box_append_text (combo, "");  /* insert space for separator */
+        gtk_combo_box_text_append_text (GTK_COMBO_BOX_TEXT (combo), "");
 
         do         /* read all predefined filters from datadir (PREFIX/share) */
         {
@@ -391,8 +377,9 @@ void miscDesignDlgCreate (GtkWidget *topWidget, GtkWidget *boxDesignDlg,
                             raw.title = g_strdup (prj.info.title);
                             raw.desc = g_strdup (prj.info.desc); /* may be NULL */
 
-                            g_array_append_val(rawFilterList, raw);
-                            gtk_combo_box_append_text (combo, prj.info.title);
+                            g_array_append_val (rawFilterList, raw);
+                            gtk_combo_box_text_append_text (
+                                GTK_COMBO_BOX_TEXT (combo), prj.info.title);
                             ++count;
                         } /* if */
                         else
@@ -433,18 +420,18 @@ void miscDesignDlgCreate (GtkWidget *topWidget, GtkWidget *boxDesignDlg,
 
 
     g_free (path);                     /* free the sub-directory path string */
-    gtk_combo_box_set_row_separator_func (combo, miscDlgComboSeparator, NULL, NULL);
-
+    gtk_combo_box_set_row_separator_func (GTK_COMBO_BOX (combo),
+                                          miscDlgComboSeparator, NULL, NULL);
 
     /* To use the wrap feature of the description label the width of lable
      * widget must must be limited. A good reference width (used here) ist the
      * combobox.
      */
-    gtk_widget_size_request (GTK_WIDGET (combo), &size);
+    gtk_widget_get_preferred_size (combo, NULL, &size);
     gtk_widget_set_size_request (lookup_widget (topWidget, MISCDLG_LABEL_DESC),
                                  size.width, -1);
 
-    gtk_combo_box_set_active (combo, 0);
+    gtk_combo_box_set_active (GTK_COMBO_BOX (combo), 0);
 
 } /* miscDesignDlgCreate() */
 
@@ -536,9 +523,9 @@ void miscDesignDlgDestroy (GtkWidget *topWidget)
         GLADE_HOOKUP_OBJECT_NO_REF (topWidget, NULL, MISCDLG_ENTRY_SAMPLE);
         GLADE_HOOKUP_OBJECT_NO_REF (topWidget, NULL, MISCDLG_COMBO_TYPE);
         GLADE_HOOKUP_OBJECT_NO_REF (topWidget, NULL, MISCDLG_SPIN_DEGREE);
-        GLADE_HOOKUP_OBJECT_NO_REF (topWidget, NULL, MISCDLG_EXPANDER_DESC);
+        GLADE_HOOKUP_OBJECT_NO_REF (topWidget, NULL, MISCDLG_FRAME_DESC);
         GLADE_HOOKUP_OBJECT_NO_REF (topWidget, NULL, MISCDLG_LABEL_DESC);
-        gtk_widget_destroy(widget);
+        gtk_widget_destroy (widget);
     } /* if */
 
 } /* miscDesignDlgDestroy() */
