@@ -1,11 +1,8 @@
-/********************* -*- mode: C; coding: utf-8 -*- *************************/
 /**
- * \file     responseDlg.c
- * \brief    Response settings/properties dialog.
- *
- * \author   Copyright (C) 2006, 2011-2012, 2020 Ralf Hoppe <ralf.hoppe@dfcgen.de>
- *
- ******************************************************************************/
+ * \file        responseDlg.c
+ * \brief       Response settings/properties dialog.
+ * \copyright   Copyright (C) 2006-2022 Ralf Hoppe <ralf.hoppe@dfcgen.de>
+ */
 
 
 /* INCLUDE FILES **************************************************************/
@@ -50,7 +47,7 @@
 
 /* LOCAL VARIABLE DEFINITIONS *************************************************/
 
-static GdkColor responseDlgColorVals[PLOT_COLOR_SIZE]; /**< Colors (modified in dialog) */
+static GdkRGBA responseDlgColorVals[PLOT_COLOR_SIZE]; /**< Colors (modified in dialog) */
 static PLOT_COLOR responseDlgColorItem; /**< Curently selected color item (labels, graph, etc.) */
 
 
@@ -61,11 +58,13 @@ static PLOT_COLOR responseDlgColorItem; /**< Curently selected color item (label
 
 static void responseDlgSetEntry (GtkWidget* topWidget, const char *name,
                                  const PLOT_UNIT *pUnit, double value);
-static void createLogGridButton (GtkWidget *topWidget, GtkTable *table,
+static void createLogGridButton (GtkWidget *topWidget, GtkGrid *table,
                                  char *logBtnName, char *gridBtnName,
                                  PLOT_AXIS *pAxis);
 static void autoScalingChanged (GtkCheckButton* button, gpointer user_data);
+static void applyStyleColor (GtkComboBox *combobox, GtkColorChooser *colorsel);
 static void colorItemChanged (GtkComboBox *combobox, gpointer user_data);
+static void colorChooserApply (GtkColorChooser *colorsel, gpointer user_data);
 static int responseDlgGetAxis (GtkWidget* topWidget, const char *widgets[],
                                 double vmin, double vmax, PLOT_AXIS *pAxis);
 
@@ -184,25 +183,19 @@ static int responseDlgGetAxis (GtkWidget* topWidget, const char *widgets[],
  *  \param pAxis        Pointer to current plot configuration of axis.
  *
  ******************************************************************************/
-static void createLogGridButton (GtkWidget *topWidget, GtkTable *table,
+static void createLogGridButton (GtkWidget *topWidget, GtkGrid *table,
                                  char *logBtnName, char *gridBtnName,
                                  PLOT_AXIS *pAxis)
 {
     GtkWidget *checkbutton = gtk_check_button_new_with_mnemonic (_("Logarithmic"));
 
-    gtk_table_attach (GTK_TABLE (table), checkbutton, 1, 3, 2, 3,
-                      (GtkAttachOptions) (GTK_FILL),
-                      (GtkAttachOptions) (0), 0, 0);
-    gtk_container_set_border_width (GTK_CONTAINER (checkbutton), 1);
+    gtk_grid_attach (table, checkbutton, 1, 2, 2, 1);
     gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (checkbutton),
                                   pAxis->flags & PLOT_AXIS_FLAG_LOG);
     GLADE_HOOKUP_OBJECT (topWidget, checkbutton, logBtnName);
 
     checkbutton = gtk_check_button_new_with_mnemonic (_("Show Grid"));
-    gtk_table_attach (GTK_TABLE (table), checkbutton, 1, 3, 3, 4,
-                      (GtkAttachOptions) (GTK_FILL),
-                      (GtkAttachOptions) (0), 0, 0);
-    gtk_container_set_border_width (GTK_CONTAINER (checkbutton), 1);
+    gtk_grid_attach (table, checkbutton, 1, 3, 2, 1);
     gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (checkbutton),
                                   pAxis->flags & PLOT_AXIS_FLAG_GRID);
     GLADE_HOOKUP_OBJECT (topWidget, checkbutton, gridBtnName);
@@ -230,9 +223,32 @@ static void autoScalingChanged (GtkCheckButton* button, gpointer user_data)
 } /* autoScalingChanged() */
 
 
+/* FUNCTION *******************************************************************/
+/** Appply currently selected color.
+ *
+ *  \param combobox     Combobox widget which identifies the item.
+ *  \param colorsel     \e GtkColorChooser widget.
+ *
+ ******************************************************************************/
+static void applyStyleColor (GtkComboBox *combobox, GtkColorChooser *colorsel)
+{
+    int idx = gtk_combo_box_get_active (combobox);
+
+    if (idx < 0)
+    {
+        idx = 0;                        /* set any, in case nothing selected */
+    } /* if */
+
+    gtk_color_chooser_get_rgba (
+        colorsel, &responseDlgColorVals[responseDlgColorItem]);
+    responseDlgColorItem = idx;           /* remind last selected color item */
+    gtk_color_chooser_set_rgba (colorsel, &responseDlgColorVals[idx]);
+
+} /* applyStyleColor() */
+
 
 /* FUNCTION *******************************************************************/
-/** This function is called if the color selection changes.
+/** This function is called if the color item \e GtkComboBox selection changes.
  *
  *  \param combobox     Combobox widget which determines the color selection.
  *  \param user_data    User data set when the signal handler was connected (unused).
@@ -240,24 +256,27 @@ static void autoScalingChanged (GtkCheckButton* button, gpointer user_data)
  ******************************************************************************/
 static void colorItemChanged (GtkComboBox *combobox, gpointer user_data)
 {
-    int idx = gtk_combo_box_get_active(combobox);
-    GtkColorSelection *colorsel = GTK_COLOR_SELECTION (
-        lookup_widget (GTK_WIDGET (combobox), RESPONSE_DLG_COLOR_SELECT));
-
-    if (idx < 0)
-    {
-        idx = 0;                        /* set any, in case nothing selected */
-    } /* if */
-
-
-    gtk_color_selection_get_current_color (
-        colorsel, &responseDlgColorVals[responseDlgColorItem]);
-    responseDlgColorItem = idx;           /* remind last selected color item */
-    gtk_color_selection_set_current_color (colorsel, &responseDlgColorVals[idx]);
+    applyStyleColor (combobox, GTK_COLOR_CHOOSER (
+        lookup_widget (GTK_WIDGET (combobox), RESPONSE_DLG_COLOR_SELECT)));
 
 } /* colorItemChanged() */
 
 
+/* FUNCTION *******************************************************************/
+/** This function is called if the selected color in \e GtkColorChooser has been applied.
+ *
+ *  \param colorsel     \e GtkColorChooser widget.
+ *  \param user_data    User data set when the signal handler was connected (unused).
+ *
+ ******************************************************************************/
+static void colorChooserApply (GtkColorChooser *colorsel, gpointer user_data)
+{
+    applyStyleColor (GTK_COMBO_BOX (
+                         lookup_widget (GTK_WIDGET (colorsel), RESPONSE_DLG_COMBO_COLOR)),
+                     colorsel);
+} /* colorChooserApply() */
+
+
 /* EXPORTED FUNCTION DEFINITIONS **********************************************/
 
 
@@ -266,31 +285,32 @@ static void colorItemChanged (GtkComboBox *combobox, gpointer user_data)
  *
  *  \attention          If anyone changes the enums PLOT_STYLE or PLOT_COLOR
  *                      from cairoPlot.h then the calls into
- *                      gtk_combo_box_append_text() must be adopted to reflect
- *                      this.
+ *                      gtk_combo_box_text_append_text() must be adopted.
  *
+ *  \param topWindow    Parent window.
  *  \param pDiag        Pointer to current plot configuration (for preset).
  *
  *  \return             Dialog widget.
  ******************************************************************************/
-GtkWidget* responseDlgCreate (PLOT_DIAG *pDiag)
+GtkWidget* responseDlgCreate (GtkWindow *topWindow, PLOT_DIAG *pDiag)
 {
-    GtkWidget *widget, *label, *box, *frame, *alignment, *table, *colorSel;
-    GtkObject *adjustment;
+    GtkWidget *widget, *label, *box, *frame, *table, *colorSel;
+    GtkAdjustment *spinAdjust;
     char *axisName;
 
     GtkWidget *responseDlg = gtk_dialog_new ();
+    gtk_window_set_transient_for (GTK_WINDOW (responseDlg), topWindow);
+    gtk_window_set_destroy_with_parent (GTK_WINDOW (responseDlg), TRUE);
 
     /* Some generic and global layout settings first
      */
     gtk_window_set_title (GTK_WINDOW (responseDlg), _("Response Settings"));
     gtk_window_set_resizable (GTK_WINDOW (responseDlg), FALSE);
-    gtk_window_set_destroy_with_parent (GTK_WINDOW (responseDlg), TRUE);
-    gtk_window_set_icon_name (GTK_WINDOW (responseDlg), GTK_STOCK_PREFERENCES);
+    gtk_window_set_icon_name (GTK_WINDOW (responseDlg), GUI_ICON_IMAGE_PREFS);
     gtk_window_set_type_hint (GTK_WINDOW (responseDlg), GDK_WINDOW_TYPE_HINT_DIALOG);
 
-    box = gtk_hbox_new (FALSE, 12);                /* x- and y-side of dialog */
-    gtk_box_pack_start (GTK_BOX (GTK_DIALOG (responseDlg)->vbox),
+    box = gtk_box_new (GTK_ORIENTATION_HORIZONTAL, 6); /* x- and y-side of dialog */
+    gtk_box_pack_start (GTK_BOX (gtk_dialog_get_content_area (GTK_DIALOG (responseDlg))),
                         box, FALSE, FALSE, 6);
 
     /* x-axis
@@ -298,11 +318,6 @@ GtkWidget* responseDlgCreate (PLOT_DIAG *pDiag)
     frame = gtk_frame_new (NULL);
     gtk_box_pack_start (GTK_BOX (box), frame, TRUE, TRUE, 0);
     gtk_container_set_border_width (GTK_CONTAINER (frame), 6);
-    gtk_frame_set_shadow_type (GTK_FRAME (frame), GTK_SHADOW_NONE);
-
-    alignment = gtk_alignment_new (0.5, 0.5, 1, 1);
-    gtk_container_add (GTK_CONTAINER (frame), alignment);
-    gtk_alignment_set_padding (GTK_ALIGNMENT (alignment), 0, 0, 12, 0);
 
     /* x-axis values
      */
@@ -313,22 +328,19 @@ GtkWidget* responseDlgCreate (PLOT_DIAG *pDiag)
     gtk_frame_set_label_widget (GTK_FRAME (frame), label);
     gtk_label_set_use_markup (GTK_LABEL (label), TRUE);
 
-    table = gtk_table_new (5, 3, FALSE);
-    gtk_container_add (GTK_CONTAINER (alignment), table);
+    table = gtk_grid_new ();                /* gtk_table_new (5, 3, FALSE); */
+    gtk_container_add (GTK_CONTAINER (frame), table);
     gtk_container_set_border_width (GTK_CONTAINER (table), 6);
-    gtk_table_set_row_spacings (GTK_TABLE (table), 6);
-    gtk_table_set_col_spacings (GTK_TABLE (table), 12);
+    gtk_widget_set_margin_start (table, GUI_INDENT_CHILD_PIXEL);
+    gtk_grid_set_row_spacing (GTK_GRID (table), 6);
+    gtk_grid_set_column_spacing (GTK_GRID (table), 6);
 
     label = gtk_label_new (_("Start"));                            /* x-start */
-    gtk_table_attach (GTK_TABLE (table), label, 0, 1, 0, 1,
-                      (GtkAttachOptions) (GTK_FILL),
-                      (GtkAttachOptions) (0), 0, 0);
-    gtk_misc_set_alignment (GTK_MISC (label), 0, 0.5);
+    gtk_grid_attach (GTK_GRID (table), label, 0, 0, 1, 1);
+    gtk_widget_set_halign (label, GTK_ALIGN_END);
 
     widget = gtk_entry_new ();
-    gtk_table_attach (GTK_TABLE (table), widget, 1, 2, 0, 1,
-                      (GtkAttachOptions) (GTK_FILL),
-                      (GtkAttachOptions) (0), 0, 0);
+    gtk_grid_attach (GTK_GRID (table), widget, 1, 0, 1, 1);
     gtk_widget_set_tooltip_text (widget, _("Start of x-axis interval"));
     gtk_entry_set_activates_default (GTK_ENTRY (widget), TRUE);
     gtk_entry_set_width_chars (GTK_ENTRY (widget), RESPONSE_DLG_WIDTH_CHARS);
@@ -340,15 +352,11 @@ GtkWidget* responseDlgCreate (PLOT_DIAG *pDiag)
     gtk_widget_grab_focus (widget);
 
     label = gtk_label_new (_("Stop"));                              /* x-stop */
-    gtk_table_attach (GTK_TABLE (table), label, 0, 1, 1, 2,
-                      (GtkAttachOptions) (GTK_FILL),
-                      (GtkAttachOptions) (0), 0, 0);
-    gtk_misc_set_alignment (GTK_MISC (label), 0, 0.5);
+    gtk_grid_attach (GTK_GRID (table), label, 0, 1, 1, 1);
+    gtk_widget_set_halign (label, GTK_ALIGN_END);
 
     widget = gtk_entry_new ();
-    gtk_table_attach (GTK_TABLE (table), widget, 1, 2, 1, 2,
-                      (GtkAttachOptions) (GTK_FILL),
-                      (GtkAttachOptions) (0), 0, 0);
+    gtk_grid_attach (GTK_GRID (table), widget, 1, 1, 1, 1);
     gtk_widget_set_tooltip_text (widget, _("End of x-axis interval"));
     gtk_entry_set_activates_default (GTK_ENTRY (widget), TRUE);
     gtk_entry_set_width_chars (GTK_ENTRY (widget), RESPONSE_DLG_WIDTH_CHARS);
@@ -358,15 +366,12 @@ GtkWidget* responseDlgCreate (PLOT_DIAG *pDiag)
     gtk_label_set_mnemonic_widget (GTK_LABEL (label), widget);
 
     label = gtk_label_new (_("Samples"));                          /* samples */
-    gtk_table_attach (GTK_TABLE (table), label, 0, 1, 4, 5,
-                      (GtkAttachOptions) (GTK_FILL),
-                      (GtkAttachOptions) (0), 0, 0);
+    gtk_grid_attach (GTK_GRID (table), label, 0, 4, 1, 1);
+    gtk_widget_set_halign (label, GTK_ALIGN_END);
 
-    adjustment = gtk_adjustment_new (0, 0, RESPONSE_DLG_SPIN_MAX, 1, 10, 0);
-    widget = gtk_spin_button_new (GTK_ADJUSTMENT (adjustment), 1, 0);
-    gtk_table_attach (GTK_TABLE (table), widget, 1, 2, 4, 5,
-                      (GtkAttachOptions) (GTK_FILL),
-                      (GtkAttachOptions) (0), 0, 0);
+    spinAdjust = gtk_adjustment_new (0, 0, RESPONSE_DLG_SPIN_MAX, 1, 10, 0);
+    widget = gtk_spin_button_new (spinAdjust, 1, 0);
+    gtk_grid_attach (GTK_GRID (table), widget, 1, 4, 1, 1);
     gtk_widget_set_tooltip_text (widget, _("The number of samples to be used (0 = all)"));
     gtk_spin_button_set_numeric (GTK_SPIN_BUTTON (widget), TRUE);
     GLADE_HOOKUP_OBJECT (responseDlg, widget, RESPONSE_DLG_SPIN_SAMPLES);
@@ -383,16 +388,12 @@ GtkWidget* responseDlgCreate (PLOT_DIAG *pDiag)
     } /* else */
 
     label = gtk_label_new (NULL);                             /* x-start unit */
-    gtk_table_attach (GTK_TABLE (table), label, 2, 3, 0, 1,
-                      (GtkAttachOptions) (GTK_FILL),
-                      (GtkAttachOptions) (0), 0, 0);
-    gtk_misc_set_alignment (GTK_MISC (label), 0, 0.5);
+    gtk_grid_attach (GTK_GRID (table), label, 2, 0, 1, 1);
+    gtk_widget_set_halign (label, GTK_ALIGN_START);
 
     widget = gtk_label_new (NULL);                             /* x-stop unit */
-    gtk_table_attach (GTK_TABLE (table), widget, 2, 3, 1, 2,
-                      (GtkAttachOptions) (GTK_FILL),
-                      (GtkAttachOptions) (0), 0, 0);
-    gtk_misc_set_alignment (GTK_MISC (widget), 0, 0.5);
+    gtk_grid_attach (GTK_GRID (table), widget, 2, 1, 1, 1);
+    gtk_widget_set_halign (label, GTK_ALIGN_START);
 
     if (pDiag->x.pUnit != NULL)
     {
@@ -405,7 +406,7 @@ GtkWidget* responseDlgCreate (PLOT_DIAG *pDiag)
         gtk_widget_hide (widget);
     } /* else */
 
-    createLogGridButton (responseDlg, GTK_TABLE (table),
+    createLogGridButton (responseDlg, GTK_GRID (table),
                          RESPONSE_DLG_CHKBTN_LOGX, RESPONSE_DLG_CHKBTN_GRIDX,
                          &pDiag->x);
 
@@ -414,11 +415,6 @@ GtkWidget* responseDlgCreate (PLOT_DIAG *pDiag)
     frame = gtk_frame_new (NULL);
     gtk_box_pack_start (GTK_BOX (box), frame, TRUE, TRUE, 0);
     gtk_container_set_border_width (GTK_CONTAINER (frame), 6);
-    gtk_frame_set_shadow_type (GTK_FRAME (frame), GTK_SHADOW_NONE);
-
-    alignment = gtk_alignment_new (0.5, 0.5, 1, 1);
-    gtk_container_add (GTK_CONTAINER (frame), alignment);
-    gtk_alignment_set_padding (GTK_ALIGNMENT (alignment), 0, 0, 12, 0);
 
     /* y-axis values
      */
@@ -429,22 +425,19 @@ GtkWidget* responseDlgCreate (PLOT_DIAG *pDiag)
     gtk_frame_set_label_widget (GTK_FRAME (frame), label);
     gtk_label_set_use_markup (GTK_LABEL (label), TRUE);
 
-    table = gtk_table_new (5, 3, FALSE);
-    gtk_container_add (GTK_CONTAINER (alignment), table);
+    table = gtk_grid_new ();                /* gtk_table_new (5, 3, FALSE); */
+    gtk_container_add (GTK_CONTAINER (frame), table);
     gtk_container_set_border_width (GTK_CONTAINER (table), 6);
-    gtk_table_set_row_spacings (GTK_TABLE (table), 6);
-    gtk_table_set_col_spacings (GTK_TABLE (table), 12);
+    gtk_widget_set_margin_start (table, GUI_INDENT_CHILD_PIXEL);
+    gtk_grid_set_row_spacing (GTK_GRID (table), 6);
+    gtk_grid_set_column_spacing (GTK_GRID (table), 6);
 
     label = gtk_label_new (_("Start"));                            /* y-start */
-    gtk_table_attach (GTK_TABLE (table), label, 0, 1, 0, 1,
-                      (GtkAttachOptions) (GTK_FILL),
-                      (GtkAttachOptions) (0), 0, 0);
-    gtk_misc_set_alignment (GTK_MISC (label), 0, 0.5);
+    gtk_grid_attach (GTK_GRID (table), label, 0, 0, 1, 1);
+    gtk_widget_set_halign (label, GTK_ALIGN_END);
 
     widget = gtk_entry_new ();
-    gtk_table_attach (GTK_TABLE (table), widget, 1, 2, 0, 1,
-                      (GtkAttachOptions) (GTK_FILL),
-                      (GtkAttachOptions) (0), 0, 0);
+    gtk_grid_attach (GTK_GRID (table), widget, 1, 0, 1, 1);
     gtk_widget_set_tooltip_text (widget, _("Start of y-axis interval"));
     gtk_widget_set_sensitive (widget, FALSE);
     gtk_entry_set_activates_default (GTK_ENTRY (widget), TRUE);
@@ -456,15 +449,11 @@ GtkWidget* responseDlgCreate (PLOT_DIAG *pDiag)
     gtk_label_set_mnemonic_widget (GTK_LABEL (label), widget);
 
     label = gtk_label_new (_("Stop"));                              /* y-stop */
-    gtk_table_attach (GTK_TABLE (table), label, 0, 1, 1, 2,
-                      (GtkAttachOptions) (GTK_FILL),
-                      (GtkAttachOptions) (0), 0, 0);
-    gtk_misc_set_alignment (GTK_MISC (label), 0, 0.5);
+    gtk_grid_attach (GTK_GRID (table), label, 0, 1, 1, 1);
+    gtk_widget_set_halign (label, GTK_ALIGN_END);
 
     widget = gtk_entry_new ();
-    gtk_table_attach (GTK_TABLE (table), widget, 1, 2, 1, 2,
-                      (GtkAttachOptions) (GTK_FILL),
-                      (GtkAttachOptions) (0), 0, 0);
+    gtk_grid_attach (GTK_GRID (table), widget, 1, 1, 1, 1);
     gtk_widget_set_tooltip_text (widget, _("End of y-axis interval"));
     gtk_widget_set_sensitive (widget, FALSE);
     gtk_entry_set_activates_default (GTK_ENTRY (widget), TRUE);
@@ -476,16 +465,12 @@ GtkWidget* responseDlgCreate (PLOT_DIAG *pDiag)
     gtk_label_set_mnemonic_widget (GTK_LABEL (label), widget);
 
     label = gtk_label_new (NULL);                             /* y-start unit */
-    gtk_table_attach (GTK_TABLE (table), label, 2, 3, 0, 1,
-                      (GtkAttachOptions) (GTK_FILL),
-                      (GtkAttachOptions) (0), 0, 0);
-    gtk_misc_set_alignment (GTK_MISC (label), 0, 0.5);
+    gtk_grid_attach (GTK_GRID (table), label, 2, 0, 1, 1);
+    gtk_widget_set_halign (label, GTK_ALIGN_START);
 
     widget = gtk_label_new (NULL);                             /* y-stop unit */
-    gtk_table_attach (GTK_TABLE (table), widget, 2, 3, 1, 2,
-                      (GtkAttachOptions) (GTK_FILL),
-                      (GtkAttachOptions) (0), 0, 0);
-    gtk_misc_set_alignment (GTK_MISC (widget), 0, 0.5);
+    gtk_grid_attach (GTK_GRID (table), widget, 2, 1, 1, 1);
+    gtk_widget_set_halign (widget, GTK_ALIGN_START);
 
     if (pDiag->y.pUnit != NULL)
     {
@@ -499,16 +484,14 @@ GtkWidget* responseDlgCreate (PLOT_DIAG *pDiag)
     } /* else */
 
 
-    createLogGridButton (responseDlg, GTK_TABLE (table),
+    createLogGridButton (responseDlg, GTK_GRID (table),
                          RESPONSE_DLG_CHKBTN_LOGY, RESPONSE_DLG_CHKBTN_GRIDY,
                          &pDiag->y);
 
     widget = gtk_check_button_new_with_mnemonic (_("Autoscaling"));
     gtk_widget_set_tooltip_text (widget, _("Autoscaling of y-axis with respect"
                                            " to minimum and maximum values in interval"));
-    gtk_table_attach (GTK_TABLE (table), widget, 1, 3, 4, 5,
-                      (GtkAttachOptions) (GTK_FILL),
-                      (GtkAttachOptions) (0), 0, 0);
+    gtk_grid_attach (GTK_GRID (table), widget, 1, 4, 2, 1);
     gtk_container_set_border_width (GTK_CONTAINER (widget), 1);
     gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (widget),
                                   pDiag->y.flags & PLOT_AXIS_FLAG_AUTO);
@@ -519,108 +502,92 @@ GtkWidget* responseDlgCreate (PLOT_DIAG *pDiag)
     /* Style settings
      */
     widget = gtk_expander_new (NULL);                        /* style xpander */
-    gtk_box_pack_start (GTK_BOX (GTK_DIALOG (responseDlg)->vbox),
+    gtk_box_pack_start (GTK_BOX (gtk_dialog_get_content_area (GTK_DIALOG (responseDlg))),
                         widget, FALSE, FALSE, 6);
-    gtk_container_set_border_width (GTK_CONTAINER (widget), 12);
+    gtk_widget_set_margin_start (widget, GUI_INDENT_CHILD_PIXEL);
     gtk_expander_set_spacing (GTK_EXPANDER (widget), 6);
 
     label = gtk_label_new (_("<b>Style</b>"));
     gtk_expander_set_label_widget (GTK_EXPANDER (widget), label);
     gtk_label_set_use_markup (GTK_LABEL (label), TRUE);
 
-    box = gtk_vbox_new (FALSE, 24);
+    box = gtk_box_new (GTK_ORIENTATION_VERTICAL, 24);
     gtk_container_add (GTK_CONTAINER (widget), box);
 
-    table = gtk_table_new (2, 3, FALSE);
+    table = gtk_grid_new ();                /* gtk_table_new (2, 3, FALSE); */
     gtk_box_pack_start (GTK_BOX (box), table, FALSE, FALSE, 6);
-    gtk_table_set_row_spacings (GTK_TABLE (table), 24);
-    gtk_table_set_col_spacings (GTK_TABLE (table), 12);
-
-    widget = gtk_arrow_new (GTK_ARROW_DOWN, GTK_SHADOW_OUT);
-    gtk_table_attach (GTK_TABLE (table), widget, 2, 3, 1, 2,
-                      (GtkAttachOptions) (GTK_EXPAND | GTK_SHRINK | GTK_FILL),
-                      (GtkAttachOptions) (GTK_EXPAND | GTK_SHRINK | GTK_FILL), 0, 0);
-    gtk_misc_set_alignment (GTK_MISC (widget), 0.2, 0.5);
+    gtk_grid_set_row_spacing (GTK_GRID (table), 6);
+    gtk_grid_set_column_spacing (GTK_GRID (table), 6);
 
     label = gtk_label_new (_("Graph"));
-    gtk_table_attach (GTK_TABLE (table), label, 0, 1, 0, 1,
-                      (GtkAttachOptions) (GTK_FILL),
-                      (GtkAttachOptions) (0), 0, 0);
-    gtk_misc_set_alignment (GTK_MISC (label), 0, 0.5);
+    gtk_grid_attach (GTK_GRID (table), label, 0, 0, 1, 1);
+    gtk_widget_set_halign (label, GTK_ALIGN_END);
 
     label = gtk_label_new (_("Color"));
-    gtk_table_attach (GTK_TABLE (table), label, 0, 1, 1, 2,
-                      (GtkAttachOptions) (GTK_FILL),
-                      (GtkAttachOptions) (0), 0, 0);
-    gtk_misc_set_alignment (GTK_MISC (label), 0, 0.5);
+    gtk_grid_attach (GTK_GRID (table), label, 0, 1, 1, 1);
+    gtk_widget_set_halign (label, GTK_ALIGN_END);
 
     responseDlgColorItem = 0;                         /* color item selection */
     memcpy (responseDlgColorVals, pDiag->colors, sizeof (responseDlgColorVals));
 
-    colorSel = gtk_color_selection_new ();
+    colorSel = gtk_color_chooser_widget_new ();
     gtk_box_pack_start (GTK_BOX (box), colorSel, FALSE, FALSE, 0);
-    gtk_color_selection_set_has_opacity_control (GTK_COLOR_SELECTION (colorSel), FALSE);
-    gtk_color_selection_set_has_palette (GTK_COLOR_SELECTION (colorSel), TRUE);
+    gtk_color_chooser_set_use_alpha (GTK_COLOR_CHOOSER (colorSel), FALSE);
+    gtk_color_chooser_set_rgba (GTK_COLOR_CHOOSER (colorSel), responseDlgColorVals);
     GLADE_HOOKUP_OBJECT (responseDlg, colorSel, RESPONSE_DLG_COLOR_SELECT);
-    gtk_color_selection_set_current_color (GTK_COLOR_SELECTION (colorSel),
-                                           responseDlgColorVals);
+    g_signal_connect (colorSel, "color-activated", G_CALLBACK (colorChooserApply), NULL);
+
     widget = gtk_event_box_new ();
-    gtk_table_attach (GTK_TABLE (table), widget, 1, 2, 0, 1,
-                      (GtkAttachOptions) (GTK_FILL),
-                      (GtkAttachOptions) (GTK_FILL), 0, 0);
+    gtk_grid_attach (GTK_GRID (table), widget, 1, 0, 1, 1);
     gtk_widget_set_tooltip_text (widget, _("Style of graph"));
 
-    box = gtk_combo_box_new_text ();
+    box = gtk_combo_box_text_new ();
     gtk_container_add (GTK_CONTAINER (widget), box);
-    gtk_combo_box_append_text (GTK_COMBO_BOX (box), _("Line (continuous)")); /* PLOT_STYLE_LINE_ONLY */
-    gtk_combo_box_append_text (GTK_COMBO_BOX (box), _("Circle (discrete)")); /* PLOT_STYLE_CIRCLE_ONLY */
-    gtk_combo_box_append_text (GTK_COMBO_BOX (box), _("Samples (discrete)")); /* PLOT_STYLE_CIRCLE_SAMPLE */
-    gtk_combo_box_append_text (GTK_COMBO_BOX (box), _("Cross (discrete)")); /* PLOT_STYLE_CROSS_ONLY */
-    gtk_combo_box_append_text (GTK_COMBO_BOX (box), _("Box (discrete)")); /* PLOT_STYLE_BOX_ONLY */
+    gtk_combo_box_text_append_text (GTK_COMBO_BOX_TEXT (box), _("Line (continuous)")); /* PLOT_STYLE_LINE_ONLY */
+    gtk_combo_box_text_append_text (GTK_COMBO_BOX_TEXT (box), _("Circle (discrete)")); /* PLOT_STYLE_CIRCLE_ONLY */
+    gtk_combo_box_text_append_text (GTK_COMBO_BOX_TEXT (box), _("Samples (discrete)")); /* PLOT_STYLE_CIRCLE_SAMPLE */
+    gtk_combo_box_text_append_text (GTK_COMBO_BOX_TEXT (box), _("Cross (discrete)")); /* PLOT_STYLE_CROSS_ONLY */
+    gtk_combo_box_text_append_text (GTK_COMBO_BOX_TEXT (box), _("Box (discrete)")); /* PLOT_STYLE_BOX_ONLY */
     GLADE_HOOKUP_OBJECT (responseDlg, box, RESPONSE_DLG_COMBO_GRAPH);
-    gtk_combo_box_set_active(GTK_COMBO_BOX (box), pDiag->style);
+    gtk_combo_box_set_active (GTK_COMBO_BOX (box), pDiag->style);
 
     widget = gtk_event_box_new ();
-    gtk_table_attach (GTK_TABLE (table), widget, 1, 2, 1, 2,
-                      (GtkAttachOptions) (GTK_FILL),
-                      (GtkAttachOptions) (GTK_FILL), 0, 0);
+    gtk_grid_attach (GTK_GRID (table), widget, 1, 1, 1, 1);
     gtk_widget_set_tooltip_text (widget, _("Choose the color item to be changed, then modify the color"));
 
-    box = gtk_combo_box_new_text ();
+    box = gtk_combo_box_text_new ();
     gtk_container_add (GTK_CONTAINER (widget), box);
-    gtk_combo_box_append_text (GTK_COMBO_BOX (box), _("Labels")); /* PLOT_COLOR_LABELS */
-    gtk_combo_box_append_text (GTK_COMBO_BOX (box), _("Grid")); /* PLOT_COLOR_GRID */
-    gtk_combo_box_append_text (GTK_COMBO_BOX (box), _("Graph")); /* PLOT_COLOR_GRAPH */
-    gtk_combo_box_append_text (GTK_COMBO_BOX (box), _("Box")); /* PLOT_COLOR_BOX */
-    gtk_combo_box_append_text (GTK_COMBO_BOX (box), _("Units")); /* PLOT_COLOR_AXIS_NAME */
+    gtk_combo_box_text_append_text (GTK_COMBO_BOX_TEXT (box), _("Labels")); /* PLOT_COLOR_LABELS */
+    gtk_combo_box_text_append_text (GTK_COMBO_BOX_TEXT (box), _("Grid")); /* PLOT_COLOR_GRID */
+    gtk_combo_box_text_append_text (GTK_COMBO_BOX_TEXT (box), _("Graph")); /* PLOT_COLOR_GRAPH */
+    gtk_combo_box_text_append_text (GTK_COMBO_BOX_TEXT (box), _("Box")); /* PLOT_COLOR_BOX */
+    gtk_combo_box_text_append_text (GTK_COMBO_BOX_TEXT (box), _("Units")); /* PLOT_COLOR_AXIS_NAME */
 
     GLADE_HOOKUP_OBJECT (responseDlg, box, RESPONSE_DLG_COMBO_COLOR);
     g_signal_connect (box, "changed", G_CALLBACK (colorItemChanged), NULL);
 
-    gtk_combo_box_set_active(GTK_COMBO_BOX (box), 0);
+    gtk_combo_box_set_active (GTK_COMBO_BOX (box), 0);
+
 
     /* Action area (buttons)
      */
-    widget = GTK_DIALOG (responseDlg)->action_area;
-    gtk_button_box_set_layout (GTK_BUTTON_BOX (widget), GTK_BUTTONBOX_END);
-
-    widget = gtk_button_new_from_stock (GTK_STOCK_HELP);
+    widget = createImageButton (GUI_BUTTON_LABEL_HELP, GUI_BUTTON_IMAGE_HELP);
     gtk_dialog_add_action_widget (GTK_DIALOG (responseDlg), widget, GTK_RESPONSE_HELP);
 #ifndef TODO
     gtk_widget_set_sensitive (widget, FALSE);
 #endif
 
-    widget = gtk_button_new_from_stock (GTK_STOCK_CANCEL);
+    widget = createImageButton (GUI_BUTTON_LABEL_CANCEL, GUI_BUTTON_IMAGE_CANCEL);
     gtk_dialog_add_action_widget (GTK_DIALOG (responseDlg), widget, GTK_RESPONSE_CANCEL);
-    GTK_WIDGET_SET_FLAGS (widget, GTK_CAN_DEFAULT);
+    gtk_widget_set_can_default (widget, TRUE);
 
-    widget = gtk_button_new_from_stock (GTK_STOCK_APPLY);
+    widget = createImageButton (GUI_BUTTON_LABEL_APPLY, GUI_BUTTON_IMAGE_APPLY);
     gtk_dialog_add_action_widget (GTK_DIALOG (responseDlg), widget, GTK_RESPONSE_APPLY);
-    GTK_WIDGET_SET_FLAGS (widget, GTK_CAN_DEFAULT);
+    gtk_widget_set_can_default (widget, TRUE);
 
-    widget = gtk_button_new_from_stock (GTK_STOCK_OK);
+    widget = createImageButton (GUI_BUTTON_LABEL_OK, GUI_BUTTON_IMAGE_OK);
     gtk_dialog_add_action_widget (GTK_DIALOG (responseDlg), widget, GTK_RESPONSE_OK);
-    GTK_WIDGET_SET_FLAGS (widget, GTK_CAN_DEFAULT);
+    gtk_widget_set_can_default (widget, TRUE);
 
     gtk_widget_grab_default (widget);
     gtk_widget_show_all (responseDlg);
