@@ -1,11 +1,8 @@
-/********************* -*- mode: C; coding: utf-8 -*- *************************/
 /**
- * \file
- *           Digital filter response window creation and callbacks.
- *
- * \author   Copyright (C) 2006, 2011, 2012, 2020 Ralf Hoppe <ralf.hoppe@dfcgen.de>
- *
- ******************************************************************************/
+ * \file        responseWin.c
+ * \brief       Digital filter response window creation and callbacks.
+ * \copyright   Copyright (C) 2006-2022 Ralf Hoppe <ralf.hoppe@dfcgen.de>
+ */
 
 
 /* INCLUDE FILES **************************************************************/
@@ -27,6 +24,7 @@
 
 /* LOCAL TYPE DECLARATIONS ****************************************************/
 
+
 /** Response window description
  */
 typedef struct
@@ -34,10 +32,15 @@ typedef struct
     RESPONSE_TYPE type;                     /**< Type of response plot/window */
     char *iconFile;                              /**< Name of icon (png) file */
     PLOT_DIAG diag;                                            /**< Plot data */
-    GdkColor colors[PLOT_COLOR_SIZE];        /**< Allocated colors to be used */
-    int points;                 /**< Points drawed on last responsePlotDraw() */
+    GdkRGBA colors[PLOT_COLOR_SIZE];         /**< Allocated colors to be used */
+    cairo_surface_t *surface;   /**< surface to store current painting (diag) */
+    int points;       /**< Number of points drawed on last responsePlotDraw() */
     GdkRectangle zoom;                 /**< Zoom coordinates (last rectangle) */
-    GdkGCValues original;                /**< Saved GdkGC values when zooming */
+#if GTK_CHECK_VERSION(3, 20, 0)
+    GdkSeat* grab;          /**< mouse grab in zoom mode, \c NULL if inactive */
+#else
+    GdkDevice* grab;
+#endif
     GtkCheckMenuItem *menuref;            /**< (Backward) menu item reference */
     GtkWidget* btnPrint;                  /**< Print button widget reference */
     GtkWidget* topWidget; /**< response plot top-level widget (NULL if not exists) */
@@ -52,20 +55,17 @@ typedef struct
 #define RESPONSE_WIN_GRAPH_THICKNESS    (2.0)           /**< Graph line width */
 
 
-/** Used GDK graphics context for zoom rectangle
- */
-#define RESPONSE_WIN_ZOOM_GC(widget)  (widget)->style->dark_gc[GTK_STATE_NORMAL]
-
 
 /* LOCAL FUNCTION DECLARATIONS ************************************************/
 
-static void drawZoomRect (RESPONSE_WIN *pDesc);
+static void plotToSurface (RESPONSE_WIN *pDesc, GtkWidget *widget);
+static void drawZoomRect (RESPONSE_WIN *pDesc, cairo_t* gc);
 static void cancelZoomMode (RESPONSE_WIN *pDesc);
 static void responseWinCreate (RESPONSE_WIN *pDesc);
-static gboolean exposeHandler (GtkWidget *widget, GdkEventExpose *event, gpointer user_data);
-static BOOL responseWinExpose (RESPONSE_WIN* pDesc);
+static gboolean responseWinDrawHandler (GtkWidget *widget, cairo_t *gc, gpointer user_data);
+static void responseWinExpose (RESPONSE_WIN* pDesc);
 static void responseWinMapped (GtkWidget* widget, gpointer user_data);
-static void responseWinDestroyed (GtkObject* object, gpointer user_data);
+static void responseWinDestroyed (GtkWidget* object, gpointer user_data);
 static void responseWinBtnPropActivate (GtkButton *button, gpointer user_data);
 static void responseWinBtnPrintActivate (GtkWidget* srcWidget, gpointer user_data);
 static gboolean responseWinKeyPress (GtkWidget *widget, GdkEventKey *event,
@@ -184,17 +184,49 @@ static RESPONSE_WIN responseWidget[RESPONSE_TYPE_SIZE] =
 /* LOCAL FUNCTION DEFINITIONS *************************************************/
 
 
-
-/* FUNCTION *******************************************************************/
-/** Cancels the zoom mode by restoring the original graphics context and
- *  erasing the last zoom rubberband. Call this function only if really in
- *  zoom mode, means the pointer is grabbed.
+/**
+ * \brief           (Re-) Create the surface and plot the response diagram into.
+ * \note            This function should be called after change of plot area size.
  *
- *  \param pDesc        Pointer to response window/widget description.
- *
- ******************************************************************************/
-static void drawZoomRect (RESPONSE_WIN *pDesc)
+ * \param[in,out]   pDesc       Pointer to response window/widget descriptor.
+ * \param[in,out]   widget      \GTkDrawingArea widget (which is the final target,
+ *                              but used only as a template for \p pDesc->surface).
+ */
+static void plotToSurface (RESPONSE_WIN *pDesc, GtkWidget *widget)
 {
+    cairo_t *gc;
+
+    int width = gtk_widget_get_allocated_width (widget);
+    int height = gtk_widget_get_allocated_height (widget);
+
+    if (pDesc->surface != NULL)
+    {
+        cairo_surface_destroy (pDesc->surface);
+    }
+
+    pDesc->surface = gdk_window_create_similar_surface (
+        gtk_widget_get_window (widget), CAIRO_CONTENT_COLOR_ALPHA, width, height);
+
+    pDesc->diag.area.x = pDesc->diag.area.y = 0;   /* set size of plot area */
+    pDesc->diag.area.width = width;
+    pDesc->diag.area.height = height;
+
+    gc = cairo_create (pDesc->surface);
+    pDesc->points = responsePlotDraw (gc, pDesc->type, &pDesc->diag);
+    cairo_destroy (gc);
+}
+
+
+/**
+ * \brief   Draw zoom rubberband into graphics context.
+ *
+ *  \param  pDesc       Pointer to response window/widget descriptor.
+ *  \param  gc          Graphics context.
+ */
+static void drawZoomRect (RESPONSE_WIN *pDesc, cairo_t* gc)
+{
+    static double dashes = 4.0;
+
     GdkRectangle rect = pDesc->zoom;
 
     if (rect.width < 0)
@@ -209,43 +241,47 @@ static void drawZoomRect (RESPONSE_WIN *pDesc)
         rect.height = -rect.height;
     } /* if */
 
-    gdk_draw_rectangle (GDK_DRAWABLE(pDesc->draw->window),  /* erase old rect */
-                        RESPONSE_WIN_ZOOM_GC(pDesc->draw), FALSE,
-                        rect.x, rect.y, rect.width, rect.height);
+    cairo_set_operator (gc, CAIRO_OPERATOR_OVER);
+    cairo_set_line_width (gc, 1);
+    cairo_set_dash (gc, &dashes, 1, 0.0);
+    cairo_set_line_cap (gc, CAIRO_LINE_CAP_BUTT);
+    cairo_set_line_join (gc, CAIRO_LINE_JOIN_MITER);
+
+    gdk_cairo_rectangle (gc, &rect);                   /* cairo_rectangle() */
+    cairo_stroke (gc);
 } /* drawZoomRect() */
 
 
 
-/* FUNCTION *******************************************************************/
-/** Cancels the zoom mode by restoring the original graphics context and
- *  erasing the last zoom rubberband. Call this function only if really in
- *  zoom mode, means the pointer is grabbed.
+/** 
+ * \brief   Cancels the zoom mode, then exposes the drawing widget.
  *
- *  \param pDesc        Pointer to response window/widget description.
- *
- ******************************************************************************/
+ * \param   pDesc       Pointer to response window/widget description.
+ */
 static void cancelZoomMode (RESPONSE_WIN *pDesc)
 {
-    drawZoomRect (pDesc);
-    gdk_pointer_ungrab (GDK_CURRENT_TIME);       /* clear zoom mode indicator */
-    gdk_keyboard_ungrab (GDK_CURRENT_TIME);
-
-    gdk_gc_set_values (RESPONSE_WIN_ZOOM_GC(pDesc->draw), &pDesc->original,
-                       GDK_GC_FUNCTION);
+    if (pDesc->grab != NULL)
+    {
+#if GTK_CHECK_VERSION(3, 20, 0)
+        gdk_seat_ungrab (pDesc->grab);
+#else
+        gdk_device_ungrab (pDesc->grab, GDK_CURRENT_TIME);
+#endif
+        pDesc->grab = NULL;
+        responseWinExpose (pDesc);
+    }
 } /* cancelZoomMode() */
 
 
 
-/* FUNCTION *******************************************************************/
-/** \e Clicked event callback emitted when a print menuitem/button is pressed.
+/**
+ * \brief   \e Clicked event callback emitted when a print menuitem/button is pressed.
  *
- *  \param[in] srcWidget \c GtkToolButton on event \e clicked, which causes
- *                       this call.
-
- *  \param user_data    Pointer to response description (::RESPONSE_WIN) as
+ * \param   srcWidget   \c GtkToolButton on event \e clicked, which causes
+ *                      this call.
+ * \param   user_data   Pointer to response description (::RESPONSE_WIN) as
  *                      supplied to function g_signal_connect().
- *
- ******************************************************************************/
+ */
 static void responseWinBtnPrintActivate (GtkWidget* srcWidget, gpointer user_data)
 {
     RESPONSE_WIN* pDesc = (RESPONSE_WIN*)user_data;
@@ -256,24 +292,20 @@ static void responseWinBtnPrintActivate (GtkWidget* srcWidget, gpointer user_dat
 
 
 
-
-
-/* FUNCTION *******************************************************************/
-/** Creates a filter response widget/window. Such a window is used to display
- *  - magnitude reponse
- *  - phase response
- *  - step response etc.
+/**
+ * \brief   Creates a filter response widget/window. Such a window is used to display
+ *          - magnitude reponse,
+ *          - phase response,
+ *          - step response etc.
  *
- *  \note               This function has changed after \e glade code generation.
+ * \param   pDesc       Pointer to response window/widget description.
  *
- *  \param pDesc        Pointer to response window/widget description.
- *
- *  \todo               Restore size of drawing area from last session
- ******************************************************************************/
+ * \todo    Restore size of drawing area from last session.
+ */
 static void responseWinCreate (RESPONSE_WIN *pDesc)
 {
     GtkWidget *vbox;
-    GtkWidget *hseparator;
+    GtkWidget *separator;
     GtkWidget *hbox;
     GtkWidget *btnSettings;
     GdkPixbuf *iconPixbuf;
@@ -296,7 +328,7 @@ static void responseWinCreate (RESPONSE_WIN *pDesc)
         g_object_unref (iconPixbuf);
     } /* if */
 
-    vbox = gtk_vbox_new (FALSE, 0);
+    vbox = gtk_box_new (GTK_ORIENTATION_VERTICAL, 0);
     gtk_container_add (GTK_CONTAINER (pDesc->topWidget), vbox);
 
     pDesc->draw = gtk_drawing_area_new ();
@@ -305,28 +337,28 @@ static void responseWinCreate (RESPONSE_WIN *pDesc)
                            GDK_BUTTON_PRESS_MASK | GDK_BUTTON_RELEASE_MASK);
     gtk_box_pack_start (GTK_BOX (vbox), pDesc->draw, TRUE, TRUE, 6);
 
-    hseparator = gtk_hseparator_new ();
-    gtk_box_pack_start (GTK_BOX (vbox), hseparator, FALSE, TRUE, 0);
+    separator = gtk_separator_new (GTK_ORIENTATION_HORIZONTAL);
+    gtk_box_pack_start (GTK_BOX (vbox), separator, FALSE, FALSE, 0);
 
-    hbox = gtk_hbox_new (FALSE, 0);
-    gtk_box_pack_start (GTK_BOX (vbox), hbox, FALSE, TRUE, 6);
+    hbox = gtk_box_new (GTK_ORIENTATION_HORIZONTAL, 0);
+    gtk_box_pack_start (GTK_BOX (vbox), hbox, FALSE, FALSE, 6);
 
     pDesc->label = gtk_label_new ("");
     gtk_box_pack_start (GTK_BOX (hbox), pDesc->label, FALSE, FALSE, 6);
     gtk_label_set_single_line_mode (GTK_LABEL (pDesc->label), TRUE);
 
-    pDesc->btnPrint = gtk_button_new_from_stock (GTK_STOCK_PRINT);
+    pDesc->btnPrint = createImageButton (GUI_BUTTON_LABEL_PRINT, GUI_BUTTON_IMAGE_PRINT);
     gtk_box_pack_end (GTK_BOX (hbox), pDesc->btnPrint, FALSE, FALSE, 6);
     g_signal_connect ((gpointer) pDesc->btnPrint, "clicked",
                       G_CALLBACK (responseWinBtnPrintActivate),
                       pDesc);
 
-    GTK_WIDGET_SET_FLAGS (pDesc->btnPrint, GTK_CAN_DEFAULT);
+    gtk_widget_set_can_default (pDesc->btnPrint, TRUE);
     gtk_widget_set_tooltip_text (pDesc->btnPrint, _("Print this response plot"));
 
-    btnSettings = gtk_button_new_from_stock (GTK_STOCK_PREFERENCES);
+    btnSettings = createImageButton (GUI_BUTTON_LABEL_PREFS, GUI_BUTTON_IMAGE_PREFS);
     gtk_box_pack_end (GTK_BOX (hbox), btnSettings, FALSE, FALSE, 6);
-    GTK_WIDGET_SET_FLAGS (btnSettings, GTK_CAN_DEFAULT);
+    gtk_widget_set_can_default (btnSettings, TRUE);
     gtk_widget_set_tooltip_text (btnSettings, _("Set response plot preferences"));
 
     gtk_widget_add_events (pDesc->topWidget, GDK_KEY_PRESS_MASK);
@@ -343,9 +375,8 @@ static void responseWinCreate (RESPONSE_WIN *pDesc)
     g_signal_connect ((gpointer) pDesc->topWidget, "key_press_event",
                       G_CALLBACK (responseWinKeyPress),
                       pDesc);
-
-    g_signal_connect ((gpointer) pDesc->draw, "expose_event",
-                      G_CALLBACK (exposeHandler),
+    g_signal_connect ((gpointer) pDesc->draw, "draw",
+                      G_CALLBACK (responseWinDrawHandler),
                       pDesc);
     g_signal_connect ((gpointer) pDesc->draw, "destroy",
                       G_CALLBACK (responseWinDestroyed),
@@ -359,7 +390,6 @@ static void responseWinCreate (RESPONSE_WIN *pDesc)
 
 
     gtk_widget_show_all (pDesc->topWidget);
-
     gtk_widget_grab_focus (btnSettings);
     gtk_widget_grab_default (btnSettings);
 
@@ -367,151 +397,144 @@ static void responseWinCreate (RESPONSE_WIN *pDesc)
 
 
 
-/* FUNCTION *******************************************************************/
-/** Invalidates the drawing area of a response window.
+/**
+ * \brief   Invalidates the drawing area of a response window.
  *
- *  \param pDesc    Pointer to response window description.
- *
- *  \return             TRUE if the associated response does really exist, else
- *                      FALSE.
- ******************************************************************************/
-static BOOL responseWinExpose (RESPONSE_WIN* pDesc)
+ * \param   pDesc   Pointer to response window description.
+ */
+static void responseWinExpose (RESPONSE_WIN* pDesc)
 {
-    if (pDesc->topWidget != NULL)
+    if ((pDesc->topWidget != NULL) && (pDesc->draw != NULL))
     {
-        gdk_window_invalidate_region (pDesc->draw->window,
-                                      gdk_drawable_get_visible_region (
-                                          GDK_DRAWABLE(pDesc->draw->window)),
-                                      FALSE);
-        return TRUE;
+        gdk_window_invalidate_rect (
+            gtk_widget_get_window (pDesc->draw), NULL, FALSE);
     } /* if */
-
-    return FALSE;
 } /* responseWinExpose() */
 
 
 
-/* FUNCTION *******************************************************************/
-/** Redraws a response widget in case an \e expose event is received.
+/**
+ * \brief   Redraws a response widget in case an \e draw event is received.
  *
- *  \param widget       Pointer to widget (GtkDrawingArea, GDK drawable), which
- *                      have to be redrawn with a particular filter response.
- *  \param event        \e expose event data.
- *  \param user_data    Pointer to response description (of type RESPONSE_WIN)
- *                      as supplied to function g_signal_connect() for \e expose
+ * \param   widget      Pointer to \c GtkDrawingArea widget, which has to be
+ *                      redrawn with a particular filter response.
+ * \param   gc          \e Cairo graphics context.
+ * \param   user_data   Pointer to response description (of type RESPONSE_WIN)
+ *                      as supplied to function g_signal_connect() for \e draw
  *                      event.
- *  \return             TRUE if the callback handled the signal, and no further
- *                      handling is needed.
- ******************************************************************************/
-static gboolean exposeHandler (GtkWidget *widget, GdkEventExpose *event, gpointer user_data)
+ * \return  \c TRUE if the callback handled the signal, and no further
+ *          handling is needed.
+ * \see     Documentation of \e GtkDrawingArea.
+ */
+static gboolean responseWinDrawHandler (GtkWidget *widget, cairo_t *gc,
+                                        gpointer user_data)
 {
-    cairo_t* cr;
     char labelString[128];
 
     RESPONSE_WIN* pDesc = user_data;
-    GdkDrawable* drawable = GDK_DRAWABLE(widget->window);
-    GdkCursor* cursor = gdk_cursor_new (GDK_WATCH);
+    GdkWindow* topWindow = gtk_widget_get_window (pDesc->topWidget);
 
-    ASSERT(pDesc != NULL);
-    gdk_window_set_cursor (pDesc->topWidget->window, cursor);
-    gdk_cursor_unref (cursor);       /* free client side resource immediately */
+    ASSERT (pDesc != NULL);
+    ASSERT (widget == pDesc->draw);
 
-    pDesc->diag.area.x = pDesc->diag.area.y = 0;     /* set size of plot area */
-    gdk_drawable_get_size (drawable, &pDesc->diag.area.width, &pDesc->diag.area.height);
-
-    cr = gdk_cairo_create (drawable);                 /* create cairo context */
-    pDesc->points = responsePlotDraw (cr, pDesc->type, &pDesc->diag);
-
-    if (pDesc->points >= 0)
+    if ((pDesc->grab != NULL) && (pDesc->surface != NULL))
     {
-        g_snprintf (labelString, sizeof(labelString), _("%d Points"), pDesc->points);
-        gtk_label_set_text (GTK_LABEL(pDesc->label), labelString);
-    } /* if */
+        cairo_save (gc);
+        cairo_set_source_surface (gc, pDesc->surface, 0, 0);
+        cairo_paint (gc);                 /* copy surface into drawing area */
+        cairo_restore (gc);
+
+        drawZoomRect (pDesc, gc);
+    }
     else
     {
-        gtk_label_set_text (GTK_LABEL(pDesc->label), "");
-    } /* else */
+        GdkCursor* cursor = gdk_cursor_new_from_name (
+            gtk_widget_get_display (pDesc->topWidget), GUI_CURSOR_IMAGE_WATCH);
+        gdk_window_set_cursor (topWindow, cursor);
+        g_object_unref (cursor);
 
+        plotToSurface (pDesc, widget);
+        // gtk_render_background (gtk_widget_get_style_context (widget), gc, ...
+        cairo_set_source_surface (gc, pDesc->surface, 0, 0);
+        cairo_paint (gc);                 /* copy surface into drawing area */
 
-    cairo_destroy(cr);                                  /* free cairo context */
-    gdk_window_set_cursor(pDesc->topWidget->window, NULL); /* restore parent cursor */
+        if (pDesc->points >= 0)
+        {
+            g_snprintf (labelString, sizeof (labelString), _("%d Points"), pDesc->points);
+            gtk_label_set_text (GTK_LABEL (pDesc->label), labelString);
+        } /* if */
+        else
+        {
+            gtk_label_set_text (GTK_LABEL (pDesc->label), "");
+        } /* else */
 
-    return TRUE;                                             /* stop emission */
-} /* exposeHandler() */
+        gdk_window_set_cursor (topWindow, NULL);   /* restore parent cursor */
+    }
+
+    return TRUE;                                           /* stop emission */
+} /* responseWinDrawHandler() */
 
 
 
-/* FUNCTION *******************************************************************/
-/** This function is called when a response widget (GtkDrawingArea) is
- *  destroyed.
+/**
+ * \brief   This function is called when a response widget (GtkDrawingArea) is
+ *          destroyed.
  *
- *  \note  The function isn't called if the window is destroyed because of
- *         main application exit (e.g. by pressing Ctrl-Q).
+ * \note    The function isn't called if the window is destroyed because of
+ *          main application exit (e.g. by pressing Ctrl-Q).
  *
- *  \param object       Response widget which was destroyed.
- *  \param user_data    Pointer to response description (of type RESPONSE_WIN)
+ * \param   object      Response widget which was destroyed.
+ * \param   user_data   Pointer to response description (of type RESPONSE_WIN)
  *                      as supplied to function g_signal_connect() for \e destroy
  *                      event.
- *
- ******************************************************************************/
-static void responseWinDestroyed(GtkObject* object, gpointer user_data)
+ */
+static void responseWinDestroyed (GtkWidget* object, gpointer user_data)
 {
     RESPONSE_WIN* pDesc = user_data;
 
     ASSERT(pDesc != NULL);
 
     pDesc->topWidget = NULL;
-    gdk_colormap_free_colors (gdk_colormap_get_system (), pDesc->colors,
-                              PLOT_COLOR_SIZE);
     gtk_check_menu_item_set_active (pDesc->menuref, FALSE);    /* update menu */
 
 } /* responseWinDestroyed() */
 
 
 
-/* FUNCTION *******************************************************************/
-/** This function is called when a response widget (GtkDrawingArea) is realized.
+/**
+ * \brief   This function is called when a response widget is realized (becomes
+ *          visible).
  *
- *  \param widget       Response widget which was realized.
- *  \param user_data    Pointer to response description (of type RESPONSE_WIN)
+ * \param   widget      Response widget (\e GtkDrawingArea) which was realized.
+ * \param   user_data   Pointer to response description (of type RESPONSE_WIN)
  *                      as supplied to function g_signal_connect() for \e realize
  *                      event.
- *
- ******************************************************************************/
+ */
 static void responseWinMapped (GtkWidget* widget, gpointer user_data)
 {
-    gboolean success[PLOT_COLOR_SIZE];
-
     RESPONSE_WIN* pDesc = user_data;
 
     ASSERT(pDesc != NULL);
     pDesc->diag.colors = pDesc->colors;      /* set pointer for color restore */
     cfgRestoreResponseSettings (pDesc->type, &pDesc->diag);
 
-    if (gdk_colormap_alloc_colors (gdk_colormap_get_system (), pDesc->colors,
-                                   PLOT_COLOR_SIZE, TRUE, TRUE, success) != 0)
-    {
-        DEBUG_LOG ("Could not allocate colors in system colormap");
-    } /* if */
-
 } /* responseWinMapped() */
 
 
 
-/* FUNCTION *******************************************************************/
-/** This function should be called when then properties button is clicked.
+/**
+ * \brief   This function should be called when then properties button is clicked.
  *
- *  \param button       Button widget.
- *  \param user_data    Pointer to response description (of type RESPONSE_WIN)
+ * \param   button      Button widget.
+ * \param   user_data   Pointer to response description (of type RESPONSE_WIN)
  *                      as supplied to function g_signal_connect().
- *
- ******************************************************************************/
+ */
 static void responseWinBtnPropActivate (GtkButton *button, gpointer user_data)
 {
     gint result;
 
     RESPONSE_WIN *pDesc = user_data;
-    GtkWidget *dialog = responseDlgCreate (&pDesc->diag);
+    GtkWidget *dialog = responseDlgCreate (GTK_WINDOW (pDesc->topWidget), &pDesc->diag);
 
     do
     {
@@ -544,18 +567,19 @@ static void responseWinBtnPropActivate (GtkButton *button, gpointer user_data)
 } /* responseWinBtnPropActivate */
 
 
+
 /* EXPORTED FUNCTION DEFINITIONS **********************************************/
 
 
-/* FUNCTION *******************************************************************/
-/** Toggles visibility of a filter response widget/window. This function
- *  should be called if a \e GtkCheckMenuItem from the \e View menu receives
- *  an \e activate event.
+/**
+ * \brief   Toggles visibility of a filter response widget/window.
+ * \note    This function should be called if a \e GtkCheckMenuItem from the
+ *          \e View menu receives an \e activate event.
  *
- *  \param menuitem     Menu item which has received the \e activate event.
- *  \param user_data    Pointer to response window type (RESPONSE_WIN_TYPE).
+ * \param   menuitem    Menu item which has received the \e activate event.
+ * \param   user_data   Pointer to response window type (RESPONSE_WIN_TYPE).
  *
- ******************************************************************************/
+ */
 void responseWinMenuActivate (GtkMenuItem* menuitem, gpointer user_data)
 {
     RESPONSE_WIN *pDesc;
@@ -569,6 +593,8 @@ void responseWinMenuActivate (GtkMenuItem* menuitem, gpointer user_data)
     {
         if (pDesc->topWidget == NULL)
         {
+            pDesc->surface = NULL;
+            pDesc->grab = NULL;
             responseWinCreate (pDesc);                   /* and create window */
 
             /* Because sometimes the expose event is missing after creation,
@@ -588,13 +614,12 @@ void responseWinMenuActivate (GtkMenuItem* menuitem, gpointer user_data)
 
 
 
-/* FUNCTION *******************************************************************/
-/** Invalidates one or all response windows for redrawing.
+/**
+ * \brief   Invalidates one or all response windows for redrawing.
  *
- *  \param type         The response window which shall be redrawn. Set this
+ * \param   type        The response window which shall be redrawn. Set this
  *                      parameter to RESPONSE_TYPE_SIZE to redraw all.
- *
- ******************************************************************************/
+ */
 void responseWinRedraw (RESPONSE_TYPE type)
 {
     RESPONSE_TYPE start, stop;
@@ -617,57 +642,54 @@ void responseWinRedraw (RESPONSE_TYPE type)
             gtk_widget_set_sensitive (responseWidget[type].btnPrint, filterValid);
         } /* if */
 
-        (void)responseWinExpose (&responseWidget[type]);
+        responseWinExpose (&responseWidget[type]);
     } /* for */
 } /* responseWinRedraw() */
 
 
-/* FUNCTION *******************************************************************/
-/** Top widget callback function on \e key_press_event. This function is used
- *  to detect zoom mode cancel.
+/**
+ * \brief   Top widget callback function on \e key_press_event.
+ * \note    This function is used to detect zoom mode cancel.
  *
- *  \param widget       Response plot widget handle (top-level).
- *  \param event        GDK event structure associated with \e key_press_event.
- *  \param user_data    Pointer to response window type (RESPONSE_WIN_TYPE).
+ * \param   widget      Response plot widget handle (top-level).
+ * \param   event       GDK event structure associated with \e key_press_event.
+ * \param   user_data   Pointer to response window type (RESPONSE_WIN_TYPE).
  *
- *  \return             TRUE if the signal shall be propagated to the GDK
- *                      default handler, else FALSE.
- ******************************************************************************/
+ * \return  \c TRUE if the signal shall be propagated to the GDK default handler,
+ *          else \c FALSE.
+ */
 static gboolean responseWinKeyPress (GtkWidget *widget, GdkEventKey *event,
                                      gpointer user_data)
 {
-    if (gdk_pointer_is_grabbed ())                           /* in zoom mode? */
-    {
-        cancelZoomMode (user_data);
-    } /* if */
+    RESPONSE_WIN* pDesc = user_data;
 
-    return FALSE;                      /* propagate signal to default handler */
+    cancelZoomMode (pDesc);
+
+    return FALSE;                    /* propagate signal to default handler */
 } /* responseWinKeyPress() */
 
 
-/* FUNCTION *******************************************************************/
-/** Drawing area widget callback function on \e button_press_event. This
- *  function is used to detect start of zoom mode.
+/**
+ * \brief   Drawing area widget callback function on \e button_press_event (mouse
+ *          button press).
+ * \note    This function is used to detect start of zoom mode.
  *
- *  \param widget       Drawing area widget handle.
- *  \param event        GDK event structure associated with \e button_press_event.
- *  \param user_data    Pointer to response window type (RESPONSE_WIN_TYPE).
+ * \param   widget      Drawing area widget handle.
+ * \param   event       GDK event structure associated with \e button_press_event.
+ * \param   user_data   Pointer to response window type (RESPONSE_WIN_TYPE).
  *
- *  \return             TRUE if the event shall be propagated to the GDK
- *                      default handler, else FALSE.
- ******************************************************************************/
+ * \return  \c TRUE if the event shall be propagated to the GDK default handler,
+ *          else \c FALSE.
+ */
 static gboolean responseWinButtonPress (GtkWidget* widget, GdkEventButton* event,
                                         gpointer user_data)
 {
     GdkCursor* cursor;
-    GdkGC* gc;
 
-    RESPONSE_WIN *pDesc = user_data;
+    RESPONSE_WIN* pDesc = user_data;
+    GdkDisplay* display = gtk_widget_get_display (pDesc->draw);
 
-    if (gdk_pointer_is_grabbed ())                           /* in zoom mode? */
-    {
-        cancelZoomMode (user_data);
-    } /* if */
+    cancelZoomMode (pDesc);
 
     if ((event->button == 1) &&                         /* left mouse button? */
         (pDesc->points > 0) &&               /* else drawing area isn't valid */
@@ -676,6 +698,13 @@ static gboolean responseWinButtonPress (GtkWidget* widget, GdkEventButton* event
         (event->y >= pDesc->diag.area.y) &&
         (event->y < pDesc->diag.area.y + pDesc->diag.area.height))
     {
+#if GTK_CHECK_VERSION(3, 20, 0)
+        GdkSeat* mouse = gdk_display_get_default_seat (display);
+#else
+        GdkDevice* mouse = gdk_device_manager_get_client_pointer (
+            gdk_display_get_device_manager (display));
+#endif
+
         DEBUG_LOG ("Mouse button 1 pressed in plot box (x = %G, y = %G)",
                    cairoPlotCoordinate (&pDesc->diag.x, pDesc->diag.area.x,
                                         pDesc->diag.area.x + pDesc->diag.area.width,
@@ -684,64 +713,63 @@ static gboolean responseWinButtonPress (GtkWidget* widget, GdkEventButton* event
                                         pDesc->diag.area.y + pDesc->diag.area.height,
                                         pDesc->diag.area.y, event->y));
 
-        cursor = gdk_cursor_new (GDK_CROSS);
+        cursor = gdk_cursor_new_from_name (display, GUI_CURSOR_IMAGE_CROSS);
 
-        if (gdk_pointer_grab (pDesc->draw->window, FALSE,
-                              GDK_BUTTON_MOTION_MASK |
-                              GDK_BUTTON_PRESS_MASK |
-                              GDK_BUTTON_RELEASE_MASK,
-                              pDesc->draw->window,
-                              cursor, event->time) == GDK_GRAB_SUCCESS)
+#if GTK_CHECK_VERSION(3, 20, 0)
+        if (gdk_seat_grab (mouse,
+                           gtk_widget_get_window (pDesc->draw),
+                           GDK_SEAT_CAPABILITY_ALL_POINTING,
+                           TRUE,
+                           cursor,
+                           (GdkEvent*) event,
+                           NULL, NULL) == GDK_GRAB_SUCCESS)
+#else
+        if (gdk_device_grab (mouse,
+                             gtk_widget_get_window (pDesc->draw),
+                             GDK_OWNERSHIP_NONE,
+                             FALSE,
+                             GDK_BUTTON_MOTION_MASK |              /* mouse */
+                             GDK_BUTTON_PRESS_MASK |
+                             GDK_BUTTON_RELEASE_MASK |
+                             GDK_KEY_PRESS_MASK,                /* keyboard */
+                             cursor,
+                             gdk_event_get_time ((GdkEvent *) event)) == GDK_GRAB_SUCCESS)
+#endif
         {
-            if (gdk_keyboard_grab (pDesc->topWidget->window, GDK_KEY_PRESS_MASK,
-                                   event->time) == GDK_GRAB_SUCCESS)
+            pDesc->grab = mouse;
+            pDesc->zoom.x = event->x;
+
+            if (pDesc->diag.y.flags & PLOT_AXIS_FLAG_AUTO)
             {
-                pDesc->zoom.x = event->x;
-
-                if (pDesc->diag.y.flags & PLOT_AXIS_FLAG_AUTO)
-                {
-                    pDesc->zoom.y = pDesc->diag.area.y;
-                } /* if */
-                else
-                {
-                    pDesc->zoom.y = event->y;
-                } /* else */
-
-                pDesc->zoom.width = pDesc->zoom.height = 0;
-
-                gc = RESPONSE_WIN_ZOOM_GC(pDesc->draw);
-                gdk_gc_get_values (gc, &pDesc->original);
-                gdk_gc_set_function (gc, GDK_XOR);
-                gdk_gc_set_line_attributes (gc, 1, GDK_LINE_ON_OFF_DASH,
-                                            GDK_CAP_BUTT, GDK_JOIN_MITER);
-                gdk_gc_set_clip_rectangle (gc, &pDesc->diag.area);
-                drawZoomRect (pDesc);
+                pDesc->zoom.y = pDesc->diag.area.y;
             } /* if */
-            else                                                     /* error */
+            else
             {
-                gdk_pointer_ungrab (GDK_CURRENT_TIME);
+                pDesc->zoom.y = event->y;
             } /* else */
+
+            pDesc->zoom.width = pDesc->zoom.height = 0;
         } /* if */
 
-        gdk_cursor_unref (cursor);   /* free client side resource immediately */
+        g_object_unref (cursor);   /* free client side resource immediately */
     } /* if */
 
-    return FALSE;                      /* propagate signal to default handler */
+    return FALSE;                    /* propagate signal to default handler */
 } /* responseWinButtonPress() */
 
 
 
-/* FUNCTION *******************************************************************/
-/** Drawing area widget callback function on \e button_release_event. This
- *  function is used to detect (regular) end of zoom mode.
+/**
+ * \brief   Drawing area widget callback function on \e button_release_event.
+ * \note    This function is used to detect (regular) end of zoom mode.
  *
- *  \param widget       Drawing area widget handle.
- *  \param event        GDK event structure associated with \e button_release_event.
- *  \param user_data    Pointer to response window type (RESPONSE_WIN_TYPE).
+ * \param   widget      Drawing area widget handle.
+ * \param   event       GDK event structure associated with \e button_release_event.
+ * \param   user_data   Pointer to response window type (RESPONSE_WIN_TYPE).
  *
- *  \return             TRUE if the event shall be propagated to the GDK
- *                      default handler, else FALSE.
- ******************************************************************************/
+ * \return  \c TRUE if the event shall be propagated to the GDK default handler,
+ *          else \c FALSE.
+ */
 static gboolean responseWinButtonRelease (GtkWidget* widget, GdkEventButton* event,
                                           gpointer user_data)
 {
@@ -750,7 +778,7 @@ static gboolean responseWinButtonRelease (GtkWidget* widget, GdkEventButton* eve
 
     RESPONSE_WIN *pDesc = user_data;
 
-    if (gdk_pointer_is_grabbed ())                           /* in zoom mode? */
+    if (pDesc->grab != NULL)
     {
         cancelZoomMode (pDesc);
 
@@ -808,7 +836,7 @@ static gboolean responseWinButtonRelease (GtkWidget* widget, GdkEventButton* eve
                     pDesc->diag.y.stop = tmpy;
                 } /* if */
 
-                (void)responseWinExpose (pDesc);    /* redraw with new ranges */
+                responseWinExpose (pDesc);          /* redraw with new ranges */
 
             } /* if */
         } /* if */
@@ -822,25 +850,24 @@ static gboolean responseWinButtonRelease (GtkWidget* widget, GdkEventButton* eve
 
 
 
-/* FUNCTION *******************************************************************/
-/** Drawing area widget callback function on \e motion_notify_event. This
- *  function is used to track pointer movements while in zoom mode.
+/**
+ * \brief   Drawing area widget callback function on \e motion_notify_event.
+ * \note    This function is used to track pointer movements while in zoom mode.
  *
- *  \param widget       Drawing area widget handle.
- *  \param event        GDK event structure associated with \e motion_notify_event.
- *  \param user_data    Pointer to response window type (RESPONSE_WIN_TYPE).
+ * \param   widget      Drawing area widget handle.
+ * \param   event       GDK event structure associated with \e motion_notify_event.
+ * \param   user_data   Pointer to response window type (RESPONSE_WIN_TYPE).
  *
- *  \return             TRUE if the event shall be propagated to the GDK
- *                      default handler, else FALSE.
- ******************************************************************************/
+ * \return  \c TRUE if the event shall be propagated to the GDK default handler,
+ *          else \c FALSE.
+ */
 static gboolean responseWinMotionNotify (GtkWidget *widget, GdkEventMotion *event,
                                          gpointer user_data)
 {
-    if (gdk_pointer_is_grabbed ())                           /* in zoom mode? */
-    {
-        RESPONSE_WIN *pDesc = user_data;
+    RESPONSE_WIN* pDesc = user_data;
 
-        drawZoomRect (pDesc);                          /* erase old rectangle */
+    if (pDesc->grab != NULL)                                 /* in zoom mode? */
+    {
         pDesc->zoom.width = event->x - pDesc->zoom.x;
 
         if (pDesc->diag.y.flags & PLOT_AXIS_FLAG_AUTO)
@@ -852,15 +879,8 @@ static gboolean responseWinMotionNotify (GtkWidget *widget, GdkEventMotion *even
             pDesc->zoom.height = event->y - pDesc->zoom.y;
         } /* else */
 
-
-        drawZoomRect (pDesc);                           /* draw new rectangle */
-
+        responseWinExpose (pDesc);                          /* draw rectangle */
     } /* if */
 
     return FALSE;                      /* propagate signal to default handler */
 } /* responseWinMotionNotify() */
-
-
-/******************************************************************************/
-/* END OF FILE                                                                */
-/******************************************************************************/
