@@ -1,12 +1,9 @@
-/********************* -*- mode: C; coding: utf-8 -*- *************************/
 /**
- * \file     support.c
- * \brief    Support functions, defines and macros, mostly for \e gettext,
- *           widget and file handling.
- *
- * \author   Copyright (C) 2006, 2011-2012, 2020 Ralf Hoppe <ralf.hoppe@dfcgen.de>
- *
- ******************************************************************************/
+ * \file        support.c
+ * \brief       Support functions, defines and macros, mostly for \e gettext,
+ *              widget and file handling.
+ * \copyright   Copyright (C) 2006-2022 Ralf Hoppe <ralf.hoppe@dfcgen.de>
+ */
 
 #include "gui.h"     /* includes base.h and config.h */
 #include "support.h"
@@ -38,7 +35,7 @@ GtkWidget* lookup_widget (GtkWidget* widget, const gchar* name)
         } /* if */
         else
         {
-            parent = widget->parent;
+            parent = gtk_widget_get_parent (widget);
         } /* else */
 
         if (parent == NULL)
@@ -88,11 +85,7 @@ gchar* getPackageDirectory (DIRECTORY_ID dir_id)
     gchar* path;
 
 #ifdef G_OS_WIN32
-#if GTK_CHECK_VERSION (2, 18, 0)
     gchar* root = g_win32_get_package_installation_directory_of_module (NULL);
-#else
-    gchar* root = g_win32_get_package_installation_directory (NULL, NULL);
-#endif
 
     if (root != NULL)                       /* installation directory found? */
     {
@@ -173,3 +166,60 @@ GdkPixbuf* createPixbufFromFile (const gchar* filename)
     return pixbuf;
 } /* createPixbufFromFile() */
 
+
+/* FUNCTION *******************************************************************/
+/** \brief Replacement for gtk_image_menu_item_new_from_stock() which is
+ *         deprecated since GTK 3.10.
+ *
+ *  \param[in]      name    Label to be applied (translated by \e gettext).
+ *  \param[in]      img     Icon image (file) name.
+ *  \param[in,out]  accel_group   The accelerator group.
+ *  \param[in]      accel_key     The accelerator key, or \c GDK_KEY_VoidSymbol
+ *                          in case there is none.
+ *
+ *  \return    A newly created menu item.
+ ******************************************************************************/
+GtkWidget* createImageMenuItem (const gchar* name, const gchar* img,
+                                GtkAccelGroup* accel_group, guint accel_key)
+{
+    GtkWidget *item = gtk_menu_item_new ();
+    GtkWidget *box = gtk_box_new (GTK_ORIENTATION_HORIZONTAL, 6);
+    GtkWidget *icon = gtk_image_new_from_icon_name (img, GTK_ICON_SIZE_MENU);
+    GtkWidget *label = gtk_accel_label_new (name);
+
+    gtk_container_add (GTK_CONTAINER (box), icon);
+    gtk_label_set_use_underline (GTK_LABEL (label), TRUE);
+    gtk_label_set_xalign (GTK_LABEL (label), 0.0);
+
+    if (accel_key != GDK_KEY_VoidSymbol)
+    {
+        gtk_widget_add_accelerator (item, "activate", accel_group,
+                                    accel_key, GDK_CONTROL_MASK, GTK_ACCEL_VISIBLE);
+    }
+
+    gtk_accel_label_set_accel_widget (GTK_ACCEL_LABEL (label), item);
+    gtk_box_pack_end (GTK_BOX (box), label, TRUE, TRUE, 0);
+    gtk_container_add (GTK_CONTAINER (item), box);
+    gtk_widget_show_all (item);
+
+    return item;
+}
+
+
+/* FUNCTION *******************************************************************/
+/** \brief Replacement for gtk_button_new_from_stock() which is deprecated
+ *         since GTK 3.10.
+ *
+ *  \param[in]      name    Label to be applied (translated by \e gettext).
+ *  \param[in]      img     Icon image (file) name.
+ *
+ *  \return    A newly created \e GtkButton.
+ ******************************************************************************/
+GtkWidget* createImageButton (const gchar* name, const gchar* img)
+{
+    GtkWidget *widget = gtk_button_new_from_icon_name (img, GTK_ICON_SIZE_BUTTON);
+    gtk_button_set_label (GTK_BUTTON (widget), name);
+    gtk_button_set_use_underline (GTK_BUTTON (widget), TRUE);
+
+    return widget;
+}
